# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: waE2E/WAWebProtobufsE2E.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from waAdv import WAAdv_pb2 as waAdv_dot_WAAdv__pb2
from waCompanionReg import (
    WAWebProtobufsCompanionReg_pb2 as waCompanionReg_dot_WAWebProtobufsCompanionReg__pb2,
)
from waMmsRetry import WAMmsRetry_pb2 as waMmsRetry_dot_WAMmsRetry__pb2
from waCommon import WACommon_pb2 as waCommon_dot_WACommon__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1dwaE2E/WAWebProtobufsE2E.proto\x12\x11WAWebProtobufsE2E\x1a\x11waAdv/WAAdv.proto\x1a/waCompanionReg/WAWebProtobufsCompanionReg.proto\x1a\x1bwaMmsRetry/WAMmsRetry.proto\x1a\x17waCommon/WACommon.proto"\xd7\x06\n\x12StickerPackMessage\x12\x15\n\rstickerPackID\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tpublisher\x18\x03 \x01(\t\x12?\n\x08stickers\x18\x04 \x03(\x0b\x32-.WAWebProtobufsE2E.StickerPackMessage.Sticker\x12\x12\n\nfileLength\x18\x05 \x01(\x04\x12\x12\n\nfileSHA256\x18\x06 \x01(\x0c\x12\x15\n\rfileEncSHA256\x18\x07 \x01(\x0c\x12\x10\n\x08mediaKey\x18\x08 \x01(\x0c\x12\x12\n\ndirectPath\x18\t \x01(\t\x12\x0f\n\x07\x63\x61ption\x18\n \x01(\t\x12\x33\n\x0b\x63ontextInfo\x18\x0b \x01(\x0b\x32\x1e.WAWebProtobufsE2E.ContextInfo\x12\x17\n\x0fpackDescription\x18\x0c \x01(\t\x12\x19\n\x11mediaKeyTimestamp\x18\r \x01(\x03\x12\x18\n\x10trayIconFileName\x18\x0e \x01(\t\x12\x1b\n\x13thumbnailDirectPath\x18\x0f \x01(\t\x12\x17\n\x0fthumbnailSHA256\x18\x10 \x01(\x0c\x12\x1a\n\x12thumbnailEncSHA256\x18\x11 \x01(\x0c\x12\x17\n\x0fthumbnailHeight\x18\x12 \x01(\r\x12\x16\n\x0ethumbnailWidth\x18\x13 \x01(\r\x12\x15\n\rimageDataHash\x18\x14 \x01(\t\x12\x17\n\x0fstickerPackSize\x18\x15 \x01(\x04\x12R\n\x11stickerPackOrigin\x18\x16 \x01(\x0e\x32\x37.WAWebProtobufsE2E.StickerPackMessage.StickerPackOrigin\x1a\x7f\n\x07Sticker\x12\x10\n\x08\x66ileName\x18\x01 \x01(\t\x12\x12\n\nisAnimated\x18\x02 \x01(\x08\x12\x0e\n\x06\x65mojis\x18\x03 \x03(\t\x12\x1a\n\x12\x61\x63\x63\x65ssibilityLabel\x18\x04 \x01(\t\x12\x10\n\x08isLottie\x18\x05 \x01(\x08\x12\x10\n\x08mimetype\x18\x06 \x01(\t"G\n\x11StickerPackOrigin\x12\x0f\n\x0b\x46IRST_PARTY\x10\x00\x12\x0f\n\x0bTHIRD_PARTY\x10\x01\x12\x10\n\x0cUSER_CREATED\x10\x02"\x85\x01\n\x12PlaceholderMessage\x12\x43\n\x04type\x18\x01 \x01(\x0e\x32\x35.WAWebProtobufsE2E.PlaceholderMessage.PlaceholderType"*\n\x0fPlaceholderType\x12\x17\n\x13MASK_LINKED_DEVICES\x10\x00"\xb3\x01\n\x0c\x42\x43\x61llMessage\x12\x11\n\tsessionID\x18\x01 \x01(\t\x12<\n\tmediaType\x18\x02 \x01(\x0e\x32).WAWebProtobufsE2E.BCallMessage.MediaType\x12\x11\n\tmasterKey\x18\x03 \x01(\x0c\x12\x0f\n\x07\x63\x61ption\x18\x04 \x01(\t".\n\tMediaType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05\x41UDIO\x10\x01\x12\t\n\x05VIDEO\x10\x02"\xbf\x04\n\x0e\x43\x61llLogMessage\x12\x0f\n\x07isVideo\x18\x01 \x01(\x08\x12\x42\n\x0b\x63\x61llOutcome\x18\x02 \x01(\x0e\x32-.WAWebProtobufsE2E.CallLogMessage.CallOutcome\x12\x14\n\x0c\x64urationSecs\x18\x03 \x01(\x03\x12<\n\x08\x63\x61llType\x18\x04 \x01(\x0e\x32*.WAWebProtobufsE2E.CallLogMessage.CallType\x12G\n\x0cparticipants\x18\x05 \x03(\x0b\x32\x31.WAWebProtobufsE2E.CallLogMessage.CallParticipant\x1a\x62\n\x0f\x43\x61llParticipant\x12\x0b\n\x03JID\x18\x01 \x01(\t\x12\x42\n\x0b\x63\x61llOutcome\x18\x02 \x01(\x0e\x32-.WAWebProtobufsE2E.CallLogMessage.CallOutcome"\x99\x01\n\x0b\x43\x61llOutcome\x12\r\n\tCONNECTED\x10\x00\x12\n\n\x06MISSED\x10\x01\x12\n\n\x06\x46\x41ILED\x10\x02\x12\x0c\n\x08REJECTED\x10\x03\x12\x16\n\x12\x41\x43\x43\x45PTED_ELSEWHERE\x10\x04\x12\x0b\n\x07ONGOING\x10\x05\x12\x13\n\x0fSILENCED_BY_DND\x10\x06\x12\x1b\n\x17SILENCED_UNKNOWN_CALLER\x10\x07";\n\x08\x43\x61llType\x12\x0b\n\x07REGULAR\x10\x00\x12\x12\n\x0eSCHEDULED_CALL\x10\x01\x12\x0e\n\nVOICE_CHAT\x10\x02"\xaa\x01\n\x18ScheduledCallEditMessage\x12!\n\x03key\x18\x01 \x01(\x0b\x32\x14.WACommon.MessageKey\x12\x46\n\x08\x65\x64itType\x18\x02 \x01(\x0e\x32\x34.WAWebProtobufsE2E.ScheduledCallEditMessage.EditType"#\n\x08\x45\x64itType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06\x43\x41NCEL\x10\x01"\xc6\x01\n\x1cScheduledCallCreationMessage\x12\x1c\n\x14scheduledTimestampMS\x18\x01 \x01(\x03\x12J\n\x08\x63\x61llType\x18\x02 \x01(\x0e\x32\x38.WAWebProtobufsE2E.ScheduledCallCreationMessage.CallType\x12\r\n\x05title\x18\x03 \x01(\t"-\n\x08\x43\x61llType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05VOICE\x10\x01\x12\t\n\x05VIDEO\x10\x02"\xd8\x01\n\x14\x45ventResponseMessage\x12K\n\x08response\x18\x01 \x01(\x0e\x32\x39.WAWebProtobufsE2E.EventResponseMessage.EventResponseType\x12\x13\n\x0btimestampMS\x18\x02 \x01(\x03\x12\x17\n\x0f\x65xtraGuestCount\x18\x03 \x01(\x05"E\n\x11\x45ventResponseType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05GOING\x10\x01\x12\r\n\tNOT_GOING\x10\x02\x12\t\n\x05MAYBE\x10\x03"\xc6\x01\n\x10PinInChatMessage\x12!\n\x03key\x18\x01 \x01(\x0b\x32\x14.WACommon.MessageKey\x12\x36\n\x04type\x18\x02 \x01(\x0e\x32(.WAWebProtobufsE2E.PinInChatMessage.Type\x12\x19\n\x11senderTimestampMS\x18\x03 \x01(\x03"<\n\x04Type\x12\x10\n\x0cUNKNOWN_TYPE\x10\x00\x12\x0f\n\x0bPIN_FOR_ALL\x10\x01\x12\x11\n\rUNPIN_FOR_ALL\x10\x02"\xf7\x01\n\x16\x42uttonsResponseMessage\x12\x1d\n\x13selectedDisplayText\x18\x02 \x01(\tH\x00\x12\x18\n\x10selectedButtonID\x18\x01 \x01(\t\x12\x33\n\x0b\x63ontextInfo\x18\x03 \x01(\x0b\x32\x1e.WAWebProtobufsE2E.ContextInfo\x12<\n\x04type\x18\x04 \x01(\x0e\x32..WAWebProtobufsE2E.ButtonsResponseMessage.Type"%\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x10\n\x0c\x44ISPLAY_TEXT\x10\x01\x42\n\n\x08response"\xd6\x07\n\x0e\x42uttonsMessage\x12\x0e\n\x04text\x18\x01 \x01(\tH\x00\x12=\n\x0f\x64ocumentMessage\x18\x02 \x01(\x0b\x32".WAWebProtobufsE2E.DocumentMessageH\x00\x12\x37\n\x0cimageMessage\x18\x03 \x01(\x0b\x32\x1f.WAWebProtobufsE2E.ImageMessageH\x00\x12\x37\n\x0cvideoMessage\x18\x04 \x01(\x0b\x32\x1f.WAWebProtobufsE2E.VideoMessageH\x00\x12=\n\x0flocationMessage\x18\x05 \x01(\x0b\x32".WAWebProtobufsE2E.LocationMessageH\x00\x12\x13\n\x0b\x63ontentText\x18\x06 \x01(\t\x12\x12\n\nfooterText\x18\x07 \x01(\t\x12\x33\n\x0b\x63ontextInfo\x18\x08 \x01(\x0b\x32\x1e.WAWebProtobufsE2E.ContextInfo\x12\x39\n\x07\x62uttons\x18\t \x03(\x0b\x32(.WAWebProtobufsE2E.ButtonsMessage.Button\x12@\n\nheaderType\x18\n \x01(\x0e\x32,.WAWebProtobufsE2E.ButtonsMessage.HeaderType\x1a\xfc\x02\n\x06\x42utton\x12\x10\n\x08\x62uttonID\x18\x01 \x01(\t\x12G\n\nbuttonText\x18\x02 \x01(\x0b\x32\x33.WAWebProtobufsE2E.ButtonsMessage.Button.ButtonText\x12;\n\x04type\x18\x03 \x01(\x0e\x32-.WAWebProtobufsE2E.ButtonsMessage.Button.Type\x12O\n\x0enativeFlowInfo\x18\x04 \x01(\x0b\x32\x37.WAWebProtobufsE2E.ButtonsMessage.Button.NativeFlowInfo\x1a\x32\n\x0eNativeFlowInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\nparamsJSON\x18\x02 \x01(\t\x1a!\n\nButtonText\x12\x13\n\x0b\x64isplayText\x18\x01 \x01(\t"2\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0c\n\x08RESPONSE\x10\x01\x12\x0f\n\x0bNATIVE_FLOW\x10\x02"`\n\nHeaderType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05\x45MPTY\x10\x01\x12\x08\n\x04TEXT\x10\x02\x12\x0c\n\x08\x44OCUMENT\x10\x03\x12\t\n\x05IMAGE\x10\x04\x12\t\n\x05VIDEO\x10\x05\x12\x0c\n\x08LOCATION\x10\x06\x42\x08\n\x06header"\xe9\x01\n\x16SecretEncryptedMessage\x12.\n\x10targetMessageKey\x18\x01 \x01(\x0b\x32\x14.WACommon.MessageKey\x12\x12\n\nencPayload\x18\x02 \x01(\x0c\x12\r\n\x05\x65ncIV\x18\x03 \x01(\x0c\x12N\n\rsecretEncType\x18\x04 \x01(\x0e\x32\x37.WAWebProtobufsE2E.SecretEncryptedMessage.SecretEncType",\n\rSecretEncType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0e\n\nEVENT_EDIT\x10\x01"\xae\x02\n\x12GroupInviteMessage\x12\x10\n\x08groupJID\x18\x01 \x01(\t\x12\x12\n\ninviteCode\x18\x02 \x01(\t\x12\x18\n\x10inviteExpiration\x18\x03 \x01(\x03\x12\x11\n\tgroupName\x18\x04 \x01(\t\x12\x15\n\rJPEGThumbnail\x18\x05 \x01(\x0c\x12\x0f\n\x07\x63\x61ption\x18\x06 \x01(\t\x12\x33\n\x0b\x63ontextInfo\x18\x07 \x01(\x0b\x32\x1e.WAWebProtobufsE2E.ContextInfo\x12\x42\n\tgroupType\x18\x08 \x01(\x0e\x32/.WAWebProtobufsE2E.GroupInviteMessage.GroupType"$\n\tGroupType\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\n\n\x06PARENT\x10\x01"\xfa\x03\n\x1aInteractiveResponseMessage\x12l\n\x19nativeFlowResponseMessage\x18\x02 \x01(\x0b\x32G.WAWebProtobufsE2E.InteractiveResponseMessage.NativeFlowResponseMessageH\x00\x12@\n\x04\x62ody\x18\x01 \x01(\x0b\x32\x32.WAWebProtobufsE2E.InteractiveResponseMessage.Body\x12\x33\n\x0b\x63ontextInfo\x18\x0f \x01(\x0b\x32\x1e.WAWebProtobufsE2E.ContextInfo\x1a\x88\x01\n\x04\x42ody\x12\x0c\n\x04text\x18\x01 \x01(\t\x12I\n\x06\x66ormat\x18\x02 \x01(\x0e\x32\x39.WAWebProtobufsE2E.InteractiveResponseMessage.Body.Format"\'\n\x06\x46ormat\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x10\n\x0c\x45XTENSIONS_1\x10\x01\x1aN\n\x19NativeFlowResponseMessage\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\nparamsJSON\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\x05\x42\x1c\n\x1ainteractiveResponseMessage"\xee\x0c\n\x12InteractiveMessage\x12R\n\x15shopStorefrontMessage\x18\x04 \x01(\x0b\x32\x31.WAWebProtobufsE2E.InteractiveMessage.ShopMessageH\x00\x12T\n\x11\x63ollectionMessage\x18\x05 \x01(\x0b\x32\x37.WAWebProtobufsE2E.InteractiveMessage.CollectionMessageH\x00\x12T\n\x11nativeFlowMessage\x18\x06 \x01(\x0b\x32\x37.WAWebProtobufsE2E.InteractiveMessage.NativeFlowMessageH\x00\x12P\n\x0f\x63\x61rouselMessage\x18\x07 \x01(\x0b\x32\x35.WAWebProtobufsE2E.InteractiveMessage.CarouselMessageH\x00\x12<\n\x06header\x18\x01 \x01(\x0b\x32,.WAWebProtobufsE2E.InteractiveMessage.Header\x12\x38\n\x04\x62ody\x18\x02 \x01(\x0b\x32*.WAWebProtobufsE2E.InteractiveMessage.Body\x12<\n\x06\x66ooter\x18\x03 \x01(\x0b\x32,.WAWebProtobufsE2E.InteractiveMessage.Footer\x12\x33\n\x0b\x63ontextInfo\x18\x0f \x01(\x0b\x32\x1e.WAWebProtobufsE2E.ContextInfo\x1a\xb5\x01\n\x0bShopMessage\x12\n\n\x02ID\x18\x01 \x01(\t\x12J\n\x07surface\x18\x02 \x01(\x0e\x32\x39.WAWebProtobufsE2E.InteractiveMessage.ShopMessage.Surface\x12\x16\n\x0emessageVersion\x18\x03 \x01(\x05"6\n\x07Surface\x12\x13\n\x0fUNKNOWN_SURFACE\x10\x00\x12\x06\n\x02\x46\x42\x10\x01\x12\x06\n\x02IG\x10\x02\x12\x06\n\x02WA\x10\x03\x1a_\n\x0f\x43\x61rouselMessage\x12\x34\n\x05\x63\x61rds\x18\x01 \x03(\x0b\x32%.WAWebProtobufsE2E.InteractiveMessage\x12\x16\n\x0emessageVersion\x18\x02 \x01(\x05\x1a\xdd\x01\n\x11NativeFlowMessage\x12Y\n\x07\x62uttons\x18\x01 \x03(\x0b\x32H.WAWebProtobufsE2E.InteractiveMessage.NativeFlowMessage.NativeFlowButton\x12\x19\n\x11messageParamsJSON\x18\x02 \x01(\t\x12\x16\n\x0emessageVersion\x18\x03 \x01(\x05\x1a:\n\x10NativeFlowButton\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x18\n\x10\x62uttonParamsJSON\x18\x02 \x01(\t\x1aG\n\x11\x43ollectionMessage\x12\x0e\n\x06\x62izJID\x18\x01 \x01(\t\x12\n\n\x02ID\x18\x02 \x01(\t\x12\x16\n\x0emessageVersion\x18\x03 \x01(\x05\x1a\x16\n\x06\x46ooter\x12\x0c\n\x04text\x18\x01 \x01(\t\x1a\x14\n\x04\x42ody\x12\x0c\n\x04text\x18\x01 \x01(\t\x1a\x94\x03\n\x06Header\x12=\n\x0f\x64ocumentMessage\x18\x03 \x01(\x0b\x32".WAWebProtobufsE2E.DocumentMessageH\x00\x12\x37\n\x0cimageMessage\x18\x04 \x01(\x0b\x32\x1f.WAWebProtobufsE2E.ImageMessageH\x00\x12\x17\n\rJPEGThumbnail\x18\x06 \x01(\x0cH\x00\x12\x37\n\x0cvideoMessage\x18\x07 \x01(\x0b\x32\x1f.WAWebProtobufsE2E.VideoMessageH\x00\x12=\n\x0flocationMessage\x18\x08 \x01(\x0b\x32".WAWebProtobufsE2E.LocationMessageH\x00\x12;\n\x0eproductMessage\x18\t \x01(\x0b\x32!.WAWebProtobufsE2E.ProductMessageH\x00\x12\r\n\x05title\x18\x01 \x01(\t\x12\x10\n\x08subtitle\x18\x02 \x01(\t\x12\x1a\n\x12hasMediaAttachment\x18\x05 \x01(\x08\x42\x07\n\x05mediaB\x14\n\x12interactiveMessage"\xde\x02\n\x13ListResponseMessage\x12\r\n\x05title\x18\x01 \x01(\t\x12\x41\n\x08listType\x18\x02 \x01(\x0e\x32/.WAWebProtobufsE2E.ListResponseMessage.ListType\x12S\n\x11singleSelectReply\x18\x03 \x01(\x0b\x32\x38.WAWebProtobufsE2E.ListResponseMessage.SingleSelectReply\x12\x33\n\x0b\x63ontextInfo\x18\x04 \x01(\x0b\x32\x1e.WAWebProtobufsE2E.ContextInfo\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x1a*\n\x11SingleSelectReply\x12\x15\n\rselectedRowID\x18\x01 \x01(\t"*\n\x08ListType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x11\n\rSINGLE_SELECT\x10\x01"\x8f\x07\n\x0bListMessage\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x12\n\nbuttonText\x18\x03 \x01(\t\x12\x39\n\x08listType\x18\x04 \x01(\x0e\x32\'.WAWebProtobufsE2E.ListMessage.ListType\x12\x38\n\x08sections\x18\x05 \x03(\x0b\x32&.WAWebProtobufsE2E.ListMessage.Section\x12G\n\x0fproductListInfo\x18\x06 \x01(\x0b\x32..WAWebProtobufsE2E.ListMessage.ProductListInfo\x12\x12\n\nfooterText\x18\x07 \x01(\t\x12\x33\n\x0b\x63ontextInfo\x18\x08 \x01(\x0b\x32\x1e.WAWebProtobufsE2E.ContextInfo\x1a\xbf\x01\n\x0fProductListInfo\x12\x46\n\x0fproductSections\x18\x01 \x03(\x0b\x32-.WAWebProtobufsE2E.ListMessage.ProductSection\x12J\n\x0bheaderImage\x18\x02 \x01(\x0b\x32\x35.WAWebProtobufsE2E.ListMessage.ProductListHeaderImage\x12\x18\n\x10\x62usinessOwnerJID\x18\x03 \x01(\t\x1a\x42\n\x16ProductListHeaderImage\x12\x11\n\tproductID\x18\x01 \x01(\t\x12\x15\n\rJPEGThumbnail\x18\x02 \x01(\x0c\x1aY\n\x0eProductSection\x12\r\n\x05title\x18\x01 \x01(\t\x12\x38\n\x08products\x18\x02 \x03(\x0b\x32&.WAWebProtobufsE2E.ListMessage.Product\x1a\x1c\n\x07Product\x12\x11\n\tproductID\x18\x01 \x01(\t\x1aJ\n\x07Section\x12\r\n\x05title\x18\x01 \x01(\t\x12\x30\n\x04rows\x18\x02 \x03(\x0b\x32".WAWebProtobufsE2E.ListMessage.Row\x1a\x38\n\x03Row\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\r\n\x05rowID\x18\x03 \x01(\t"<\n\x08ListType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x11\n\rSINGLE_SELECT\x10\x01\x12\x10\n\x0cPRODUCT_LIST\x10\x02"\x93\x04\n\x0cOrderMessage\x12\x0f\n\x07orderID\x18\x01 \x01(\t\x12\x11\n\tthumbnail\x18\x02 \x01(\x0c\x12\x11\n\titemCount\x18\x03 \x01(\x05\x12;\n\x06status\x18\x04 \x01(\x0e\x32+.WAWebProtobufsE2E.OrderMessage.OrderStatus\x12=\n\x07surface\x18\x05 \x01(\x0e\x32,.WAWebProtobufsE2E.OrderMessage.OrderSurface\x12\x0f\n\x07message\x18\x06 \x01(\t\x12\x12\n\norderTitle\x18\x07 \x01(\t\x12\x11\n\tsellerJID\x18\x08 \x01(\t\x12\r\n\x05token\x18\t \x01(\t\x12\x17\n\x0ftotalAmount1000\x18\n \x01(\x03\x12\x19\n\x11totalCurrencyCode\x18\x0b \x01(\t\x12\x33\n\x0b\x63ontextInfo\x18\x11 \x01(\x0b\x32\x1e.WAWebProtobufsE2E.ContextInfo\x12\x16\n\x0emessageVersion\x18\x0c \x01(\x05\x12\x33\n\x15orderRequestMessageID\x18\r \x01(\x0b\x32\x14.WACommon.MessageKey"\x1b\n\x0cOrderSurface\x12\x0b\n\x07\x43\x41TALOG\x10\x01"6\n\x0bOrderStatus\x12\x0b\n\x07INQUIRY\x10\x01\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x02\x12\x0c\n\x08\x44\x45\x43LINED\x10\x03"\xb3\x01\n\x14PaymentInviteMessage\x12H\n\x0bserviceType\x18\x01 \x01(\x0e\x32\x33.WAWebProtobufsE2E.PaymentInviteMessage.ServiceType\x12\x17\n\x0f\x65xpiryTimestamp\x18\x02 \x01(\x03"8\n\x0bServiceType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05\x46\x42PAY\x10\x01\x12\x08\n\x04NOVI\x10\x02\x12\x07\n\x03UPI\x10\x03"\xd0\x0b\n\x17HighlyStructuredMessage\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x13\n\x0b\x65lementName\x18\x02 \x01(\t\x12\x0e\n\x06params\x18\x03 \x03(\t\x12\x12\n\nfallbackLg\x18\x04 \x01(\t\x12\x12\n\nfallbackLc\x18\x05 \x01(\t\x12]\n\x11localizableParams\x18\x06 \x03(\x0b\x32\x42.WAWebProtobufsE2E.HighlyStructuredMessage.HSMLocalizableParameter\x12\x17\n\x0f\x64\x65terministicLg\x18\x07 \x01(\t\x12\x17\n\x0f\x64\x65terministicLc\x18\x08 \x01(\t\x12\x37\n\x0bhydratedHsm\x18\t \x01(\x0b\x32".WAWebProtobufsE2E.TemplateMessage\x1a\x8a\t\n\x17HSMLocalizableParameter\x12\x62\n\x08\x63urrency\x18\x02 \x01(\x0b\x32N.WAWebProtobufsE2E.HighlyStructuredMessage.HSMLocalizableParameter.HSMCurrencyH\x00\x12\x62\n\x08\x64\x61teTime\x18\x03 \x01(\x0b\x32N.WAWebProtobufsE2E.HighlyStructuredMessage.HSMLocalizableParameter.HSMDateTimeH\x00\x12\x0f\n\x07\x64\x65\x66\x61ult\x18\x01 \x01(\t\x1a\xce\x06\n\x0bHSMDateTime\x12x\n\tcomponent\x18\x01 \x01(\x0b\x32\x63.WAWebProtobufsE2E.HighlyStructuredMessage.HSMLocalizableParameter.HSMDateTime.HSMDateTimeComponentH\x00\x12x\n\tunixEpoch\x18\x02 \x01(\x0b\x32\x63.WAWebProtobufsE2E.HighlyStructuredMessage.HSMLocalizableParameter.HSMDateTime.HSMDateTimeUnixEpochH\x00\x1a\x8e\x04\n\x14HSMDateTimeComponent\x12\x84\x01\n\tdayOfWeek\x18\x01 \x01(\x0e\x32q.WAWebProtobufsE2E.HighlyStructuredMessage.HSMLocalizableParameter.HSMDateTime.HSMDateTimeComponent.DayOfWeekType\x12\x0c\n\x04year\x18\x02 \x01(\r\x12\r\n\x05month\x18\x03 \x01(\r\x12\x12\n\ndayOfMonth\x18\x04 \x01(\r\x12\x0c\n\x04hour\x18\x05 \x01(\r\x12\x0e\n\x06minute\x18\x06 \x01(\r\x12\x82\x01\n\x08\x63\x61lendar\x18\x07 \x01(\x0e\x32p.WAWebProtobufsE2E.HighlyStructuredMessage.HSMLocalizableParameter.HSMDateTime.HSMDateTimeComponent.CalendarType".\n\x0c\x43\x61lendarType\x12\r\n\tGREGORIAN\x10\x01\x12\x0f\n\x0bSOLAR_HIJRI\x10\x02"k\n\rDayOfWeekType\x12\n\n\x06MONDAY\x10\x01\x12\x0b\n\x07TUESDAY\x10\x02\x12\r\n\tWEDNESDAY\x10\x03\x12\x0c\n\x08THURSDAY\x10\x04\x12\n\n\x06\x46RIDAY\x10\x05\x12\x0c\n\x08SATURDAY\x10\x06\x12\n\n\x06SUNDAY\x10\x07\x1a)\n\x14HSMDateTimeUnixEpoch\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\x42\x0f\n\rdatetimeOneof\x1a\x37\n\x0bHSMCurrency\x12\x14\n\x0c\x63urrencyCode\x18\x01 \x01(\t\x12\x12\n\namount1000\x18\x02 \x01(\x03\x42\x0c\n\nparamOneof"\xe8\x12\n\'PeerDataOperationRequestResponseMessage\x12U\n\x1cpeerDataOperationRequestType\x18\x01 \x01(\x0e\x32/.WAWebProtobufsE2E.PeerDataOperationRequestType\x12\x10\n\x08stanzaID\x18\x02 \x01(\t\x12s\n\x17peerDataOperationResult\x18\x03 \x03(\x0b\x32R.WAWebProtobufsE2E.PeerDataOperationRequestResponseMessage.PeerDataOperationResult\x1a\xde\x10\n\x17PeerDataOperationResult\x12H\n\x11mediaUploadResult\x18\x01 \x01(\x0e\x32-.WAMmsRetry.MediaRetryNotification.ResultType\x12\x39\n\x0estickerMessage\x18\x02 \x01(\x0b\x32!.WAWebProtobufsE2E.StickerMessage\x12\x83\x01\n\x13linkPreviewResponse\x18\x03 \x01(\x0b\x32\x66.WAWebProtobufsE2E.PeerDataOperationRequestResponseMessage.PeerDataOperationResult.LinkPreviewResponse\x12\x9d\x01\n placeholderMessageResendResponse\x18\x04 \x01(\x0b\x32s.WAWebProtobufsE2E.PeerDataOperationRequestResponseMessage.PeerDataOperationResult.PlaceholderMessageResendResponse\x12\x94\x01\n\x1fwaffleNonceFetchRequestResponse\x18\x05 \x01(\x0b\x32k.WAWebProtobufsE2E.PeerDataOperationRequestResponseMessage.PeerDataOperationResult.WaffleNonceFetchResponse\x12\xa9\x01\n&fullHistorySyncOnDemandRequestResponse\x18\x06 \x01(\x0b\x32y.WAWebProtobufsE2E.PeerDataOperationRequestResponseMessage.PeerDataOperationResult.FullHistorySyncOnDemandRequestResponse\x12\xa2\x01\n&companionMetaNonceFetchRequestResponse\x18\x07 \x01(\x0b\x32r.WAWebProtobufsE2E.PeerDataOperationRequestResponseMessage.PeerDataOperationResult.CompanionMetaNonceFetchResponse\x1a\x30\n\x1f\x43ompanionMetaNonceFetchResponse\x12\r\n\x05nonce\x18\x01 \x01(\t\x1a<\n\x18WaffleNonceFetchResponse\x12\r\n\x05nonce\x18\x01 \x01(\t\x12\x11\n\twaEntFbid\x18\x02 \x01(\t\x1a\x8b\x02\n&FullHistorySyncOnDemandRequestResponse\x12R\n\x0frequestMetadata\x18\x01 \x01(\x0b\x32\x39.WAWebProtobufsE2E.FullHistorySyncOnDemandRequestMetadata\x12\x8c\x01\n\x0cresponseCode\x18\x02 \x01(\x0e\x32v.WAWebProtobufsE2E.PeerDataOperationRequestResponseMessage.PeerDataOperationResult.FullHistorySyncOnDemandResponseCode\x1a?\n PlaceholderMessageResendResponse\x12\x1b\n\x13webMessageInfoBytes\x18\x01 \x01(\x0c\x1a\xef\x03\n\x13LinkPreviewResponse\x12\x0b\n\x03URL\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x11\n\tthumbData\x18\x04 \x01(\x0c\x12\x14\n\x0c\x63\x61nonicalURL\x18\x05 \x01(\t\x12\x11\n\tmatchText\x18\x06 \x01(\t\x12\x13\n\x0bpreviewType\x18\x07 \x01(\t\x12\x9c\x01\n\x0bhqThumbnail\x18\x08 \x01(\x0b\x32\x86\x01.WAWebProtobufsE2E.PeerDataOperationRequestResponseMessage.PeerDataOperationResult.LinkPreviewResponse.LinkPreviewHighQualityThumbnail\x1a\xb6\x01\n\x1fLinkPreviewHighQualityThumbnail\x12\x12\n\ndirectPath\x18\x01 \x01(\t\x12\x11\n\tthumbHash\x18\x02 \x01(\t\x12\x14\n\x0c\x65ncThumbHash\x18\x03 \x01(\t\x12\x10\n\x08mediaKey\x18\x04 \x01(\x0c\x12\x1b\n\x13mediaKeyTimestampMS\x18\x05 \x01(\x03\x12\x12\n\nthumbWidth\x18\x06 \x01(\x05\x12\x13\n\x0bthumbHeight\x18\x07 \x01(\x05"\xfe\x01\n#FullHistorySyncOnDemandResponseCode\x12\x13\n\x0fREQUEST_SUCCESS\x10\x00\x12\x18\n\x14REQUEST_TIME_EXPIRED\x10\x01\x12\x1c\n\x18\x44\x45\x43LINED_SHARING_HISTORY\x10\x02\x12\x11\n\rGENERIC_ERROR\x10\x03\x12$\n ERROR_REQUEST_ON_NON_SMB_PRIMARY\x10\x04\x12%\n!ERROR_HOSTED_DEVICE_NOT_CONNECTED\x10\x05\x12*\n&ERROR_HOSTED_DEVICE_LOGIN_TIME_NOT_SET\x10\x06"\x9b\x05\n\x17HistorySyncNotification\x12\x12\n\nfileSHA256\x18\x01 \x01(\x0c\x12\x12\n\nfileLength\x18\x02 \x01(\x04\x12\x10\n\x08mediaKey\x18\x03 \x01(\x0c\x12\x15\n\rfileEncSHA256\x18\x04 \x01(\x0c\x12\x12\n\ndirectPath\x18\x05 \x01(\t\x12L\n\x08syncType\x18\x06 \x01(\x0e\x32:.WAWebProtobufsE2E.HistorySyncNotification.HistorySyncType\x12\x12\n\nchunkOrder\x18\x07 \x01(\r\x12\x19\n\x11originalMessageID\x18\x08 \x01(\t\x12\x10\n\x08progress\x18\t \x01(\r\x12$\n\x1coldestMsgInChunkTimestampSec\x18\n \x01(\x03\x12)\n!initialHistBootstrapInlinePayload\x18\x0b \x01(\x0c\x12 \n\x18peerDataRequestSessionID\x18\x0c \x01(\t\x12i\n&fullHistorySyncOnDemandRequestMetadata\x18\r \x01(\x0b\x32\x39.WAWebProtobufsE2E.FullHistorySyncOnDemandRequestMetadata\x12\x11\n\tencHandle\x18\x0e \x01(\t"\x9a\x01\n\x0fHistorySyncType\x12\x15\n\x11INITIAL_BOOTSTRAP\x10\x00\x12\x15\n\x11INITIAL_STATUS_V3\x10\x01\x12\x08\n\x04\x46ULL\x10\x02\x12\n\n\x06RECENT\x10\x03\x12\r\n\tPUSH_NAME\x10\x04\x12\x15\n\x11NON_BLOCKING_DATA\x10\x05\x12\r\n\tON_DEMAND\x10\x06\x12\x0e\n\nNO_HISTORY\x10\x07"\xa4\x01\n\x1dRequestWelcomeMessageMetadata\x12W\n\x0elocalChatState\x18\x01 \x01(\x0e\x32?.WAWebProtobufsE2E.RequestWelcomeMessageMetadata.LocalChatState"*\n\x0eLocalChatState\x12\t\n\x05\x45MPTY\x10\x00\x12\r\n\tNON_EMPTY\x10\x01"\xef\x0f\n\x0fProtocolMessage\x12!\n\x03key\x18\x01 \x01(\x0b\x32\x14.WACommon.MessageKey\x12\x35\n\x04type\x18\x02 \x01(\x0e\x32\'.WAWebProtobufsE2E.ProtocolMessage.Type\x12\x1b\n\x13\x65phemeralExpiration\x18\x04 \x01(\r\x12!\n\x19\x65phemeralSettingTimestamp\x18\x05 \x01(\x03\x12K\n\x17historySyncNotification\x18\x06 \x01(\x0b\x32*.WAWebProtobufsE2E.HistorySyncNotification\x12\x45\n\x14\x61ppStateSyncKeyShare\x18\x07 \x01(\x0b\x32\'.WAWebProtobufsE2E.AppStateSyncKeyShare\x12I\n\x16\x61ppStateSyncKeyRequest\x18\x08 \x01(\x0b\x32).WAWebProtobufsE2E.AppStateSyncKeyRequest\x12i\n&initialSecurityNotificationSettingSync\x18\t \x01(\x0b\x32\x39.WAWebProtobufsE2E.InitialSecurityNotificationSettingSync\x12\x61\n"appStateFatalExceptionNotification\x18\n \x01(\x0b\x32\x35.WAWebProtobufsE2E.AppStateFatalExceptionNotification\x12=\n\x10\x64isappearingMode\x18\x0b \x01(\x0b\x32#.WAWebProtobufsE2E.DisappearingMode\x12\x31\n\reditedMessage\x18\x0e \x01(\x0b\x32\x1a.WAWebProtobufsE2E.Message\x12\x13\n\x0btimestampMS\x18\x0f \x01(\x03\x12[\n\x1fpeerDataOperationRequestMessage\x18\x10 \x01(\x0b\x32\x32.WAWebProtobufsE2E.PeerDataOperationRequestMessage\x12k\n\'peerDataOperationRequestResponseMessage\x18\x11 \x01(\x0b\x32:.WAWebProtobufsE2E.PeerDataOperationRequestResponseMessage\x12\x41\n\x12\x62otFeedbackMessage\x18\x12 \x01(\x0b\x32%.WAWebProtobufsE2E.BotFeedbackMessage\x12\x12\n\ninvokerJID\x18\x13 \x01(\t\x12W\n\x1drequestWelcomeMessageMetadata\x18\x14 \x01(\x0b\x32\x30.WAWebProtobufsE2E.RequestWelcomeMessageMetadata\x12\x41\n\x12mediaNotifyMessage\x18\x15 \x01(\x0b\x32%.WAWebProtobufsE2E.MediaNotifyMessage\x12_\n!cloudApiThreadControlNotification\x18\x16 \x01(\x0b\x32\x34.WAWebProtobufsE2E.CloudAPIThreadControlNotification\x12Y\n\x1elidMigrationMappingSyncMessage\x18\x17 \x01(\x0b\x32\x31.WAWebProtobufsE2E.LIDMigrationMappingSyncMessage"\x94\x05\n\x04Type\x12\n\n\x06REVOKE\x10\x00\x12\x15\n\x11\x45PHEMERAL_SETTING\x10\x03\x12\x1b\n\x17\x45PHEMERAL_SYNC_RESPONSE\x10\x04\x12\x1d\n\x19HISTORY_SYNC_NOTIFICATION\x10\x05\x12\x1c\n\x18\x41PP_STATE_SYNC_KEY_SHARE\x10\x06\x12\x1e\n\x1a\x41PP_STATE_SYNC_KEY_REQUEST\x10\x07\x12\x1f\n\x1bMSG_FANOUT_BACKFILL_REQUEST\x10\x08\x12.\n*INITIAL_SECURITY_NOTIFICATION_SETTING_SYNC\x10\t\x12*\n&APP_STATE_FATAL_EXCEPTION_NOTIFICATION\x10\n\x12\x16\n\x12SHARE_PHONE_NUMBER\x10\x0b\x12\x10\n\x0cMESSAGE_EDIT\x10\x0e\x12\'\n#PEER_DATA_OPERATION_REQUEST_MESSAGE\x10\x10\x12\x30\n,PEER_DATA_OPERATION_REQUEST_RESPONSE_MESSAGE\x10\x11\x12\x1b\n\x17REQUEST_WELCOME_MESSAGE\x10\x12\x12\x18\n\x14\x42OT_FEEDBACK_MESSAGE\x10\x13\x12\x18\n\x14MEDIA_NOTIFY_MESSAGE\x10\x14\x12)\n%CLOUD_API_THREAD_CONTROL_NOTIFICATION\x10\x15\x12\x1e\n\x1aLID_MIGRATION_MAPPING_SYNC\x10\x16\x12\x14\n\x10REMINDER_MESSAGE\x10\x17\x12\x1f\n\x1b\x42OT_MEMU_ONBOARDING_MESSAGE\x10\x18\x12\x1a\n\x16STATUS_MENTION_MESSAGE\x10\x19"\xa5\x02\n!CloudAPIThreadControlNotification\x12Z\n\x06status\x18\x01 \x01(\x0e\x32J.WAWebProtobufsE2E.CloudAPIThreadControlNotification.CloudAPIThreadControl\x12%\n\x1dsenderNotificationTimestampMS\x18\x02 \x01(\x03\x12\x13\n\x0b\x63onsumerLid\x18\x03 \x01(\t\x12\x1b\n\x13\x63onsumerPhoneNumber\x18\x04 \x01(\t"K\n\x15\x43loudAPIThreadControl\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x12\n\x0e\x43ONTROL_PASSED\x10\x01\x12\x11\n\rCONTROL_TAKEN\x10\x02"\xc1\t\n\x12\x42otFeedbackMessage\x12(\n\nmessageKey\x18\x01 \x01(\x0b\x32\x14.WACommon.MessageKey\x12\x43\n\x04kind\x18\x02 \x01(\x0e\x32\x35.WAWebProtobufsE2E.BotFeedbackMessage.BotFeedbackKind\x12\x0c\n\x04text\x18\x03 \x01(\t\x12\x14\n\x0ckindNegative\x18\x04 \x01(\x04\x12\x14\n\x0ckindPositive\x18\x05 \x01(\x04\x12\x44\n\nkindReport\x18\x06 \x01(\x0e\x32\x30.WAWebProtobufsE2E.BotFeedbackMessage.ReportKind"\x19\n\nReportKind\x12\x0b\n\x07GENERIC\x10\x00"M\n\x1f\x42otFeedbackKindMultiplePositive\x12*\n&BOT_FEEDBACK_MULTIPLE_POSITIVE_GENERIC\x10\x01"\xcb\x03\n\x1f\x42otFeedbackKindMultipleNegative\x12*\n&BOT_FEEDBACK_MULTIPLE_NEGATIVE_GENERIC\x10\x01\x12*\n&BOT_FEEDBACK_MULTIPLE_NEGATIVE_HELPFUL\x10\x02\x12.\n*BOT_FEEDBACK_MULTIPLE_NEGATIVE_INTERESTING\x10\x04\x12+\n\'BOT_FEEDBACK_MULTIPLE_NEGATIVE_ACCURATE\x10\x08\x12\'\n#BOT_FEEDBACK_MULTIPLE_NEGATIVE_SAFE\x10\x10\x12(\n$BOT_FEEDBACK_MULTIPLE_NEGATIVE_OTHER\x10 \x12*\n&BOT_FEEDBACK_MULTIPLE_NEGATIVE_REFUSED\x10@\x12:\n5BOT_FEEDBACK_MULTIPLE_NEGATIVE_NOT_VISUALLY_APPEALING\x10\x80\x01\x12\x38\n3BOT_FEEDBACK_MULTIPLE_NEGATIVE_NOT_RELEVANT_TO_TEXT\x10\x80\x02"\x83\x03\n\x0f\x42otFeedbackKind\x12\x19\n\x15\x42OT_FEEDBACK_POSITIVE\x10\x00\x12!\n\x1d\x42OT_FEEDBACK_NEGATIVE_GENERIC\x10\x01\x12!\n\x1d\x42OT_FEEDBACK_NEGATIVE_HELPFUL\x10\x02\x12%\n!BOT_FEEDBACK_NEGATIVE_INTERESTING\x10\x03\x12"\n\x1e\x42OT_FEEDBACK_NEGATIVE_ACCURATE\x10\x04\x12\x1e\n\x1a\x42OT_FEEDBACK_NEGATIVE_SAFE\x10\x05\x12\x1f\n\x1b\x42OT_FEEDBACK_NEGATIVE_OTHER\x10\x06\x12!\n\x1d\x42OT_FEEDBACK_NEGATIVE_REFUSED\x10\x07\x12\x30\n,BOT_FEEDBACK_NEGATIVE_NOT_VISUALLY_APPEALING\x10\x08\x12.\n*BOT_FEEDBACK_NEGATIVE_NOT_RELEVANT_TO_TEXT\x10\t"\xb5\x06\n\x0cVideoMessage\x12\x0b\n\x03URL\x18\x01 \x01(\t\x12\x10\n\x08mimetype\x18\x02 \x01(\t\x12\x12\n\nfileSHA256\x18\x03 \x01(\x0c\x12\x12\n\nfileLength\x18\x04 \x01(\x04\x12\x0f\n\x07seconds\x18\x05 \x01(\r\x12\x10\n\x08mediaKey\x18\x06 \x01(\x0c\x12\x0f\n\x07\x63\x61ption\x18\x07 \x01(\t\x12\x13\n\x0bgifPlayback\x18\x08 \x01(\x08\x12\x0e\n\x06height\x18\t \x01(\r\x12\r\n\x05width\x18\n \x01(\r\x12\x15\n\rfileEncSHA256\x18\x0b \x01(\x0c\x12H\n\x16interactiveAnnotations\x18\x0c \x03(\x0b\x32(.WAWebProtobufsE2E.InteractiveAnnotation\x12\x12\n\ndirectPath\x18\r \x01(\t\x12\x19\n\x11mediaKeyTimestamp\x18\x0e \x01(\x03\x12\x15\n\rJPEGThumbnail\x18\x10 \x01(\x0c\x12\x33\n\x0b\x63ontextInfo\x18\x11 \x01(\x0b\x32\x1e.WAWebProtobufsE2E.ContextInfo\x12\x18\n\x10streamingSidecar\x18\x12 \x01(\x0c\x12\x43\n\x0egifAttribution\x18\x13 \x01(\x0e\x32+.WAWebProtobufsE2E.VideoMessage.Attribution\x12\x10\n\x08viewOnce\x18\x14 \x01(\x08\x12\x1b\n\x13thumbnailDirectPath\x18\x15 \x01(\t\x12\x17\n\x0fthumbnailSHA256\x18\x16 \x01(\x0c\x12\x1a\n\x12thumbnailEncSHA256\x18\x17 \x01(\x0c\x12\x11\n\tstaticURL\x18\x18 \x01(\t\x12=\n\x0b\x61nnotations\x18\x19 \x03(\x0b\x32(.WAWebProtobufsE2E.InteractiveAnnotation\x12\x1a\n\x12\x61\x63\x63\x65ssibilityLabel\x18\x1a \x01(\t\x12:\n\x0fprocessedVideos\x18\x1b \x03(\x0b\x32!.WAWebProtobufsE2E.ProcessedVideo"-\n\x0b\x41ttribution\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05GIPHY\x10\x01\x12\t\n\x05TENOR\x10\x02"\xcb\t\n\x13\x45xtendedTextMessage\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x13\n\x0bmatchedText\x18\x02 \x01(\t\x12\x14\n\x0c\x63\x61nonicalURL\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\r\n\x05title\x18\x06 \x01(\t\x12\x10\n\x08textArgb\x18\x07 \x01(\x07\x12\x16\n\x0e\x62\x61\x63kgroundArgb\x18\x08 \x01(\x07\x12=\n\x04\x66ont\x18\t \x01(\x0e\x32/.WAWebProtobufsE2E.ExtendedTextMessage.FontType\x12G\n\x0bpreviewType\x18\n \x01(\x0e\x32\x32.WAWebProtobufsE2E.ExtendedTextMessage.PreviewType\x12\x15\n\rJPEGThumbnail\x18\x10 \x01(\x0c\x12\x33\n\x0b\x63ontextInfo\x18\x11 \x01(\x0b\x32\x1e.WAWebProtobufsE2E.ContextInfo\x12\x17\n\x0f\x64oNotPlayInline\x18\x12 \x01(\x08\x12\x1b\n\x13thumbnailDirectPath\x18\x13 \x01(\t\x12\x17\n\x0fthumbnailSHA256\x18\x14 \x01(\x0c\x12\x1a\n\x12thumbnailEncSHA256\x18\x15 \x01(\x0c\x12\x10\n\x08mediaKey\x18\x16 \x01(\x0c\x12\x19\n\x11mediaKeyTimestamp\x18\x17 \x01(\x03\x12\x17\n\x0fthumbnailHeight\x18\x18 \x01(\r\x12\x16\n\x0ethumbnailWidth\x18\x19 \x01(\r\x12W\n\x13inviteLinkGroupType\x18\x1a \x01(\x0e\x32:.WAWebProtobufsE2E.ExtendedTextMessage.InviteLinkGroupType\x12&\n\x1einviteLinkParentGroupSubjectV2\x18\x1b \x01(\t\x12(\n inviteLinkParentGroupThumbnailV2\x18\x1c \x01(\x0c\x12Y\n\x15inviteLinkGroupTypeV2\x18\x1d \x01(\x0e\x32:.WAWebProtobufsE2E.ExtendedTextMessage.InviteLinkGroupType\x12\x10\n\x08viewOnce\x18\x1e \x01(\x08\x12\x13\n\x0bvideoHeight\x18\x1f \x01(\r\x12\x12\n\nvideoWidth\x18  \x01(\r"H\n\x13InviteLinkGroupType\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\n\n\x06PARENT\x10\x01\x12\x07\n\x03SUB\x10\x02\x12\x0f\n\x0b\x44\x45\x46\x41ULT_SUB\x10\x03"^\n\x0bPreviewType\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05VIDEO\x10\x01\x12\x0f\n\x0bPLACEHOLDER\x10\x04\x12\t\n\x05IMAGE\x10\x05\x12\x11\n\rPAYMENT_LINKS\x10\x06\x12\x0b\n\x07PROFILE\x10\x07"\xa4\x01\n\x08\x46ontType\x12\n\n\x06SYSTEM\x10\x00\x12\x0f\n\x0bSYSTEM_TEXT\x10\x01\x12\r\n\tFB_SCRIPT\x10\x02\x12\x0f\n\x0bSYSTEM_BOLD\x10\x06\x12\x19\n\x15MORNINGBREEZE_REGULAR\x10\x07\x12\x15\n\x11\x43\x41LISTOGA_REGULAR\x10\x08\x12\x12\n\x0e\x45XO2_EXTRABOLD\x10\t\x12\x15\n\x11\x43OURIERPRIME_BOLD\x10\n"\xf8\x02\n\x0eInvoiceMessage\x12\x0c\n\x04note\x18\x01 \x01(\t\x12\r\n\x05token\x18\x02 \x01(\t\x12H\n\x0e\x61ttachmentType\x18\x03 \x01(\x0e\x32\x30.WAWebProtobufsE2E.InvoiceMessage.AttachmentType\x12\x1a\n\x12\x61ttachmentMimetype\x18\x04 \x01(\t\x12\x1a\n\x12\x61ttachmentMediaKey\x18\x05 \x01(\x0c\x12#\n\x1b\x61ttachmentMediaKeyTimestamp\x18\x06 \x01(\x03\x12\x1c\n\x14\x61ttachmentFileSHA256\x18\x07 \x01(\x0c\x12\x1f\n\x17\x61ttachmentFileEncSHA256\x18\x08 \x01(\x0c\x12\x1c\n\x14\x61ttachmentDirectPath\x18\t \x01(\t\x12\x1f\n\x17\x61ttachmentJPEGThumbnail\x18\n \x01(\x0c"$\n\x0e\x41ttachmentType\x12\t\n\x05IMAGE\x10\x00\x12\x07\n\x03PDF\x10\x01"\x8d\x07\n\x0cImageMessage\x12\x0b\n\x03URL\x18\x01 \x01(\t\x12\x10\n\x08mimetype\x18\x02 \x01(\t\x12\x0f\n\x07\x63\x61ption\x18\x03 \x01(\t\x12\x12\n\nfileSHA256\x18\x04 \x01(\x0c\x12\x12\n\nfileLength\x18\x05 \x01(\x04\x12\x0e\n\x06height\x18\x06 \x01(\r\x12\r\n\x05width\x18\x07 \x01(\r\x12\x10\n\x08mediaKey\x18\x08 \x01(\x0c\x12\x15\n\rfileEncSHA256\x18\t \x01(\x0c\x12H\n\x16interactiveAnnotations\x18\n \x03(\x0b\x32(.WAWebProtobufsE2E.InteractiveAnnotation\x12\x12\n\ndirectPath\x18\x0b \x01(\t\x12\x19\n\x11mediaKeyTimestamp\x18\x0c \x01(\x03\x12\x15\n\rJPEGThumbnail\x18\x10 \x01(\x0c\x12\x33\n\x0b\x63ontextInfo\x18\x11 \x01(\x0b\x32\x1e.WAWebProtobufsE2E.ContextInfo\x12\x18\n\x10\x66irstScanSidecar\x18\x12 \x01(\x0c\x12\x17\n\x0f\x66irstScanLength\x18\x13 \x01(\r\x12\x19\n\x11\x65xperimentGroupID\x18\x14 \x01(\r\x12\x14\n\x0cscansSidecar\x18\x15 \x01(\x0c\x12\x13\n\x0bscanLengths\x18\x16 \x03(\r\x12\x1c\n\x14midQualityFileSHA256\x18\x17 \x01(\x0c\x12\x1f\n\x17midQualityFileEncSHA256\x18\x18 \x01(\x0c\x12\x10\n\x08viewOnce\x18\x19 \x01(\x08\x12\x1b\n\x13thumbnailDirectPath\x18\x1a \x01(\t\x12\x17\n\x0fthumbnailSHA256\x18\x1b \x01(\x0c\x12\x1a\n\x12thumbnailEncSHA256\x18\x1c \x01(\x0c\x12\x11\n\tstaticURL\x18\x1d \x01(\t\x12=\n\x0b\x61nnotations\x18\x1e \x03(\x0b\x32(.WAWebProtobufsE2E.InteractiveAnnotation\x12H\n\x0fimageSourceType\x18\x1f \x01(\x0e\x32/.WAWebProtobufsE2E.ImageMessage.ImageSourceType\x12\x1a\n\x12\x61\x63\x63\x65ssibilityLabel\x18  \x01(\t"D\n\x0fImageSourceType\x12\x0e\n\nUSER_IMAGE\x10\x00\x12\x10\n\x0c\x41I_GENERATED\x10\x01\x12\x0f\n\x0b\x41I_MODIFIED\x10\x02"\xd4\x1a\n\x0b\x43ontextInfo\x12\x10\n\x08stanzaID\x18\x01 \x01(\t\x12\x13\n\x0bparticipant\x18\x02 \x01(\t\x12\x31\n\rquotedMessage\x18\x03 \x01(\x0b\x32\x1a.WAWebProtobufsE2E.Message\x12\x11\n\tremoteJID\x18\x04 \x01(\t\x12\x14\n\x0cmentionedJID\x18\x0f \x03(\t\x12\x18\n\x10\x63onversionSource\x18\x12 \x01(\t\x12\x16\n\x0e\x63onversionData\x18\x13 \x01(\x0c\x12\x1e\n\x16\x63onversionDelaySeconds\x18\x14 \x01(\r\x12\x17\n\x0f\x66orwardingScore\x18\x15 \x01(\r\x12\x13\n\x0bisForwarded\x18\x16 \x01(\x08\x12<\n\x08quotedAd\x18\x17 \x01(\x0b\x32*.WAWebProtobufsE2E.ContextInfo.AdReplyInfo\x12,\n\x0eplaceholderKey\x18\x18 \x01(\x0b\x32\x14.WACommon.MessageKey\x12\x12\n\nexpiration\x18\x19 \x01(\r\x12!\n\x19\x65phemeralSettingTimestamp\x18\x1a \x01(\x03\x12\x1d\n\x15\x65phemeralSharedSecret\x18\x1b \x01(\x0c\x12K\n\x0f\x65xternalAdReply\x18\x1c \x01(\x0b\x32\x32.WAWebProtobufsE2E.ContextInfo.ExternalAdReplyInfo\x12"\n\x1a\x65ntryPointConversionSource\x18\x1d \x01(\t\x12\x1f\n\x17\x65ntryPointConversionApp\x18\x1e \x01(\t\x12(\n entryPointConversionDelaySeconds\x18\x1f \x01(\r\x12=\n\x10\x64isappearingMode\x18  \x01(\x0b\x32#.WAWebProtobufsE2E.DisappearingMode\x12\x31\n\nactionLink\x18! \x01(\x0b\x32\x1d.WAWebProtobufsE2E.ActionLink\x12\x14\n\x0cgroupSubject\x18" \x01(\t\x12\x16\n\x0eparentGroupJID\x18# \x01(\t\x12\x17\n\x0ftrustBannerType\x18% \x01(\t\x12\x19\n\x11trustBannerAction\x18& \x01(\r\x12\x11\n\tisSampled\x18\' \x01(\x08\x12\x36\n\rgroupMentions\x18( \x03(\x0b\x32\x1f.WAWebProtobufsE2E.GroupMention\x12\x33\n\x03utm\x18) \x01(\x0b\x32&.WAWebProtobufsE2E.ContextInfo.UTMInfo\x12\x65\n\x1e\x66orwardedNewsletterMessageInfo\x18+ \x01(\x0b\x32=.WAWebProtobufsE2E.ContextInfo.ForwardedNewsletterMessageInfo\x12]\n\x1a\x62usinessMessageForwardInfo\x18, \x01(\x0b\x32\x39.WAWebProtobufsE2E.ContextInfo.BusinessMessageForwardInfo\x12\x1b\n\x13smbClientCampaignID\x18- \x01(\t\x12\x1b\n\x13smbServerCampaignID\x18. \x01(\t\x12M\n\x12\x64\x61taSharingContext\x18/ \x01(\x0b\x32\x31.WAWebProtobufsE2E.ContextInfo.DataSharingContext\x12\x1f\n\x17\x61lwaysShowAdAttribution\x18\x30 \x01(\x08\x12Q\n\x14\x66\x65\x61tureEligibilities\x18\x31 \x01(\x0b\x32\x33.WAWebProtobufsE2E.ContextInfo.FeatureEligibilities\x12*\n"entryPointConversionExternalSource\x18\x32 \x01(\t\x12*\n"entryPointConversionExternalMedium\x18\x33 \x01(\t\x12\x13\n\x0b\x63twaSignals\x18\x36 \x01(\t\x12\x13\n\x0b\x63twaPayload\x18\x37 \x01(\x0c\x12[\n\x19\x66orwardedAiBotMessageInfo\x18\x38 \x01(\x0b\x32\x38.WAWebProtobufsE2E.ContextInfo.ForwardedAIBotMessageInfo\x1a\x9e\x02\n\x1e\x46orwardedNewsletterMessageInfo\x12\x15\n\rnewsletterJID\x18\x01 \x01(\t\x12\x17\n\x0fserverMessageID\x18\x02 \x01(\x05\x12\x16\n\x0enewsletterName\x18\x03 \x01(\t\x12^\n\x0b\x63ontentType\x18\x04 \x01(\x0e\x32I.WAWebProtobufsE2E.ContextInfo.ForwardedNewsletterMessageInfo.ContentType\x12\x19\n\x11\x61\x63\x63\x65ssibilityText\x18\x05 \x01(\t"9\n\x0b\x43ontentType\x12\n\n\x06UPDATE\x10\x01\x12\x0f\n\x0bUPDATE_CARD\x10\x02\x12\r\n\tLINK_CARD\x10\x03\x1a\xf3\x04\n\x13\x45xternalAdReplyInfo\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04\x62ody\x18\x02 \x01(\t\x12O\n\tmediaType\x18\x03 \x01(\x0e\x32<.WAWebProtobufsE2E.ContextInfo.ExternalAdReplyInfo.MediaType\x12\x14\n\x0cthumbnailURL\x18\x04 \x01(\t\x12\x10\n\x08mediaURL\x18\x05 \x01(\t\x12\x11\n\tthumbnail\x18\x06 \x01(\x0c\x12\x12\n\nsourceType\x18\x07 \x01(\t\x12\x10\n\x08sourceID\x18\x08 \x01(\t\x12\x11\n\tsourceURL\x18\t \x01(\t\x12\x19\n\x11\x63ontainsAutoReply\x18\n \x01(\x08\x12\x1d\n\x15renderLargerThumbnail\x18\x0b \x01(\x08\x12\x19\n\x11showAdAttribution\x18\x0c \x01(\x08\x12\x10\n\x08\x63twaClid\x18\r \x01(\t\x12\x0b\n\x03ref\x18\x0e \x01(\t\x12\x1b\n\x13\x63lickToWhatsappCall\x18\x0f \x01(\x08\x12!\n\x19\x61\x64\x43ontextPreviewDismissed\x18\x10 \x01(\x08\x12\x11\n\tsourceApp\x18\x11 \x01(\t\x12%\n\x1d\x61utomatedGreetingMessageShown\x18\x12 \x01(\x08\x12\x1b\n\x13greetingMessageBody\x18\x13 \x01(\t\x12\x12\n\nctaPayload\x18\x14 \x01(\t\x12\x14\n\x0c\x64isableNudge\x18\x15 \x01(\x08\x12\x18\n\x10originalImageURL\x18\x16 \x01(\t"+\n\tMediaType\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05IMAGE\x10\x01\x12\t\n\x05VIDEO\x10\x02\x1a\xc3\x01\n\x0b\x41\x64ReplyInfo\x12\x16\n\x0e\x61\x64vertiserName\x18\x01 \x01(\t\x12G\n\tmediaType\x18\x02 \x01(\x0e\x32\x34.WAWebProtobufsE2E.ContextInfo.AdReplyInfo.MediaType\x12\x15\n\rJPEGThumbnail\x18\x10 \x01(\x0c\x12\x0f\n\x07\x63\x61ption\x18\x11 \x01(\t"+\n\tMediaType\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05IMAGE\x10\x01\x12\t\n\x05VIDEO\x10\x02\x1a\x65\n\x14\x46\x65\x61tureEligibilities\x12\x19\n\x11\x63\x61nnotBeReactedTo\x18\x01 \x01(\x08\x12\x16\n\x0e\x63\x61nnotBeRanked\x18\x02 \x01(\x08\x12\x1a\n\x12\x63\x61nRequestFeedback\x18\x03 \x01(\x08\x1a\xcb\x02\n\x12\x44\x61taSharingContext\x12\x18\n\x10showMmDisclosure\x18\x01 \x01(\x08\x12%\n\x1d\x65ncryptedSignalTokenConsented\x18\x02 \x01(\t\x12P\n\nparameters\x18\x03 \x03(\x0b\x32<.WAWebProtobufsE2E.ContextInfo.DataSharingContext.Parameters\x1a\xa1\x01\n\nParameters\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x12\n\nstringData\x18\x02 \x01(\t\x12\x0f\n\x07intData\x18\x03 \x01(\x03\x12\x11\n\tfloatData\x18\x04 \x01(\x02\x12N\n\x08\x63ontents\x18\x05 \x01(\x0b\x32<.WAWebProtobufsE2E.ContextInfo.DataSharingContext.Parameters\x1aQ\n\x19\x46orwardedAIBotMessageInfo\x12\x0f\n\x07\x62otName\x18\x01 \x01(\t\x12\x0e\n\x06\x62otJID\x18\x02 \x01(\t\x12\x13\n\x0b\x63reatorName\x18\x03 \x01(\t\x1a\x31\n\x07UTMInfo\x12\x11\n\tutmSource\x18\x01 \x01(\t\x12\x13\n\x0butmCampaign\x18\x02 \x01(\t\x1a\x36\n\x1a\x42usinessMessageForwardInfo\x12\x18\n\x10\x62usinessOwnerJID\x18\x01 \x01(\t"\xdd\x04\n\x11\x42otPluginMetadata\x12\x45\n\x08provider\x18\x01 \x01(\x0e\x32\x33.WAWebProtobufsE2E.BotPluginMetadata.SearchProvider\x12\x43\n\npluginType\x18\x02 \x01(\x0e\x32/.WAWebProtobufsE2E.BotPluginMetadata.PluginType\x12\x17\n\x0fthumbnailCDNURL\x18\x03 \x01(\t\x12\x1a\n\x12profilePhotoCDNURL\x18\x04 \x01(\t\x12\x19\n\x11searchProviderURL\x18\x05 \x01(\t\x12\x16\n\x0ereferenceIndex\x18\x06 \x01(\r\x12\x1a\n\x12\x65xpectedLinksCount\x18\x07 \x01(\r\x12\x13\n\x0bsearchQuery\x18\t \x01(\t\x12\x34\n\x16parentPluginMessageKey\x18\n \x01(\x0b\x32\x14.WACommon.MessageKey\x12H\n\x0f\x64\x65precatedField\x18\x0b \x01(\x0e\x32/.WAWebProtobufsE2E.BotPluginMetadata.PluginType\x12I\n\x10parentPluginType\x18\x0c \x01(\x0e\x32/.WAWebProtobufsE2E.BotPluginMetadata.PluginType"#\n\nPluginType\x12\t\n\x05REELS\x10\x01\x12\n\n\x06SEARCH\x10\x02"3\n\x0eSearchProvider\x12\x08\n\x04\x42ING\x10\x01\x12\n\n\x06GOOGLE\x10\x02\x12\x0b\n\x07SUPPORT\x10\x03"\x92\x02\n\x10\x42otMediaMetadata\x12\x12\n\nfileSHA256\x18\x01 \x01(\t\x12\x10\n\x08mediaKey\x18\x02 \x01(\t\x12\x15\n\rfileEncSHA256\x18\x03 \x01(\t\x12\x12\n\ndirectPath\x18\x04 \x01(\t\x12\x19\n\x11mediaKeyTimestamp\x18\x05 \x01(\x03\x12\x10\n\x08mimetype\x18\x06 \x01(\t\x12L\n\x0forientationType\x18\x07 \x01(\x0e\x32\x33.WAWebProtobufsE2E.BotMediaMetadata.OrientationType"2\n\x0fOrientationType\x12\n\n\x06\x43\x45NTER\x10\x01\x12\x08\n\x04LEFT\x10\x02\x12\t\n\x05RIGHT\x10\x03"\x99\x03\n\x13\x42otReminderMetadata\x12/\n\x11requestMessageKey\x18\x01 \x01(\x0b\x32\x14.WACommon.MessageKey\x12\x45\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\x35.WAWebProtobufsE2E.BotReminderMetadata.ReminderAction\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x1c\n\x14nextTriggerTimestamp\x18\x04 \x01(\x04\x12K\n\tfrequency\x18\x05 \x01(\x0e\x32\x38.WAWebProtobufsE2E.BotReminderMetadata.ReminderFrequency"O\n\x11ReminderFrequency\x12\x08\n\x04ONCE\x10\x01\x12\t\n\x05\x44\x41ILY\x10\x02\x12\n\n\x06WEEKLY\x10\x03\x12\x0c\n\x08\x42IWEEKLY\x10\x04\x12\x0b\n\x07MONTHLY\x10\x05"@\n\x0eReminderAction\x12\n\n\x06NOTIFY\x10\x01\x12\n\n\x06\x43REATE\x10\x02\x12\n\n\x06\x44\x45LETE\x10\x03\x12\n\n\x06UPDATE\x10\x04"\x9a\x02\n\x10\x42otModelMetadata\x12@\n\tmodelType\x18\x01 \x01(\x0e\x32-.WAWebProtobufsE2E.BotModelMetadata.ModelType\x12R\n\x12premiumModelStatus\x18\x02 \x01(\x0e\x32\x36.WAWebProtobufsE2E.BotModelMetadata.PremiumModelStatus";\n\x12PremiumModelStatus\x12\r\n\tAVAILABLE\x10\x01\x12\x16\n\x12QUOTA_EXCEED_LIMIT\x10\x02"3\n\tModelType\x12\x0e\n\nLLAMA_PROD\x10\x01\x12\x16\n\x12LLAMA_PROD_PREMIUM\x10\x02"\xd0\x01\n\x15\x42otCapabilityMetadata\x12P\n\x0c\x63\x61pabilities\x18\x01 \x03(\x0e\x32:.WAWebProtobufsE2E.BotCapabilityMetadata.BotCapabilityType"e\n\x11\x42otCapabilityType\x12\x16\n\x12PROGRESS_INDICATOR\x10\x01\x12\x19\n\x15RICH_RESPONSE_HEADING\x10\x02\x12\x1d\n\x19RICH_RESPONSE_NESTED_LIST\x10\x03"\xa4\x01\n\x12\x42otImagineMetadata\x12\x46\n\x0bimagineType\x18\x01 \x01(\x0e\x32\x31.WAWebProtobufsE2E.BotImagineMetadata.ImagineType"F\n\x0bImagineType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07IMAGINE\x10\x01\x12\x08\n\x04MEMU\x10\x02\x12\t\n\x05\x46LASH\x10\x03\x12\x08\n\x04\x45\x44IT\x10\x04"\xdb\x02\n\x12MessageAssociation\x12N\n\x0f\x61ssociationType\x18\x01 \x01(\x0e\x32\x35.WAWebProtobufsE2E.MessageAssociation.AssociationType\x12.\n\x10parentMessageKey\x18\x02 \x01(\x0b\x32\x14.WACommon.MessageKey\x12\x14\n\x0cmessageIndex\x18\x03 \x01(\x05"\xae\x01\n\x0f\x41ssociationType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0f\n\x0bMEDIA_ALBUM\x10\x01\x12\x0e\n\nBOT_PLUGIN\x10\x02\x12\x15\n\x11\x45VENT_COVER_IMAGE\x10\x03\x12\x0f\n\x0bSTATUS_POLL\x10\x04\x12\x18\n\x14HD_VIDEO_DUAL_UPLOAD\x10\x05\x12\x1b\n\x17STATUS_TAPPABLE_MESSAGE\x10\x06\x12\x0e\n\nMEDIA_POLL\x10\x07"\xcb\x04\n\x12MessageContextInfo\x12\x41\n\x12\x64\x65viceListMetadata\x18\x01 \x01(\x0b\x32%.WAWebProtobufsE2E.DeviceListMetadata\x12!\n\x19\x64\x65viceListMetadataVersion\x18\x02 \x01(\x05\x12\x15\n\rmessageSecret\x18\x03 \x01(\x0c\x12\x14\n\x0cpaddingBytes\x18\x04 \x01(\x0c\x12"\n\x1amessageAddOnDurationInSecs\x18\x05 \x01(\r\x12\x18\n\x10\x62otMessageSecret\x18\x06 \x01(\x0c\x12\x33\n\x0b\x62otMetadata\x18\x07 \x01(\x0b\x32\x1e.WAWebProtobufsE2E.BotMetadata\x12\x1d\n\x15reportingTokenVersion\x18\x08 \x01(\x05\x12\\\n\x16messageAddOnExpiryType\x18\t \x01(\x0e\x32<.WAWebProtobufsE2E.MessageContextInfo.MessageAddonExpiryType\x12\x41\n\x12messageAssociation\x18\n \x01(\x0b\x32%.WAWebProtobufsE2E.MessageAssociation\x12\x18\n\x10\x63\x61piCreatedGroup\x18\x0b \x01(\x08\x12\x16\n\x0esupportPayload\x18\x0c \x01(\t"=\n\x16MessageAddonExpiryType\x12\n\n\x06STATIC\x10\x01\x12\x17\n\x13\x44\x45PENDENT_ON_PARENT\x10\x02"\xbd\x05\n\x16HydratedTemplateButton\x12^\n\x10quickReplyButton\x18\x01 \x01(\x0b\x32\x42.WAWebProtobufsE2E.HydratedTemplateButton.HydratedQuickReplyButtonH\x00\x12P\n\turlButton\x18\x02 \x01(\x0b\x32;.WAWebProtobufsE2E.HydratedTemplateButton.HydratedURLButtonH\x00\x12R\n\ncallButton\x18\x03 \x01(\x0b\x32<.WAWebProtobufsE2E.HydratedTemplateButton.HydratedCallButtonH\x00\x12\r\n\x05index\x18\x04 \x01(\r\x1a\xfe\x01\n\x11HydratedURLButton\x12\x13\n\x0b\x64isplayText\x18\x01 \x01(\t\x12\x0b\n\x03URL\x18\x02 \x01(\t\x12\x19\n\x11\x63onsentedUsersURL\x18\x03 \x01(\t\x12p\n\x13webviewPresentation\x18\x04 \x01(\x0e\x32S.WAWebProtobufsE2E.HydratedTemplateButton.HydratedURLButton.WebviewPresentationType":\n\x17WebviewPresentationType\x12\x08\n\x04\x46ULL\x10\x01\x12\x08\n\x04TALL\x10\x02\x12\x0b\n\x07\x43OMPACT\x10\x03\x1a>\n\x12HydratedCallButton\x12\x13\n\x0b\x64isplayText\x18\x01 \x01(\t\x12\x13\n\x0bphoneNumber\x18\x02 \x01(\t\x1a;\n\x18HydratedQuickReplyButton\x12\x13\n\x0b\x64isplayText\x18\x01 \x01(\t\x12\n\n\x02ID\x18\x02 \x01(\tB\x10\n\x0ehydratedButton"\xbb\x03\n\x11PaymentBackground\x12\n\n\x02ID\x18\x01 \x01(\t\x12\x12\n\nfileLength\x18\x02 \x01(\x04\x12\r\n\x05width\x18\x03 \x01(\r\x12\x0e\n\x06height\x18\x04 \x01(\r\x12\x10\n\x08mimetype\x18\x05 \x01(\t\x12\x17\n\x0fplaceholderArgb\x18\x06 \x01(\x07\x12\x10\n\x08textArgb\x18\x07 \x01(\x07\x12\x13\n\x0bsubtextArgb\x18\x08 \x01(\x07\x12\x41\n\tmediaData\x18\t \x01(\x0b\x32..WAWebProtobufsE2E.PaymentBackground.MediaData\x12\x37\n\x04type\x18\n \x01(\x0e\x32).WAWebProtobufsE2E.PaymentBackground.Type\x1aw\n\tMediaData\x12\x10\n\x08mediaKey\x18\x01 \x01(\x0c\x12\x19\n\x11mediaKeyTimestamp\x18\x02 \x01(\x03\x12\x12\n\nfileSHA256\x18\x03 \x01(\x0c\x12\x15\n\rfileEncSHA256\x18\x04 \x01(\x0c\x12\x12\n\ndirectPath\x18\x05 \x01(\t" \n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x01"\xb1\x03\n\x10\x44isappearingMode\x12@\n\tinitiator\x18\x01 \x01(\x0e\x32-.WAWebProtobufsE2E.DisappearingMode.Initiator\x12<\n\x07trigger\x18\x02 \x01(\x0e\x32+.WAWebProtobufsE2E.DisappearingMode.Trigger\x12\x1a\n\x12initiatorDeviceJID\x18\x03 \x01(\t\x12\x15\n\rinitiatedByMe\x18\x04 \x01(\x08"\x7f\n\x07Trigger\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x10\n\x0c\x43HAT_SETTING\x10\x01\x12\x13\n\x0f\x41\x43\x43OUNT_SETTING\x10\x02\x12\x0f\n\x0b\x42ULK_CHANGE\x10\x03\x12\x1b\n\x17\x42IZ_SUPPORTS_FB_HOSTING\x10\x04\x12\x12\n\x0eUNKNOWN_GROUPS\x10\x05"i\n\tInitiator\x12\x13\n\x0f\x43HANGED_IN_CHAT\x10\x00\x12\x13\n\x0fINITIATED_BY_ME\x10\x01\x12\x16\n\x12INITIATED_BY_OTHER\x10\x02\x12\x1a\n\x16\x42IZ_UPGRADE_FB_HOSTING\x10\x03"\x8e\x02\n\x0eProcessedVideo\x12\x12\n\ndirectPath\x18\x01 \x01(\t\x12\x12\n\nfileSHA256\x18\x02 \x01(\x0c\x12\x0e\n\x06height\x18\x03 \x01(\r\x12\r\n\x05width\x18\x04 \x01(\r\x12\x12\n\nfileLength\x18\x05 \x01(\x04\x12\x0f\n\x07\x62itrate\x18\x06 \x01(\r\x12?\n\x07quality\x18\x07 \x01(\x0e\x32..WAWebProtobufsE2E.ProcessedVideo.VideoQuality\x12\x14\n\x0c\x63\x61pabilities\x18\x08 \x03(\t"9\n\x0cVideoQuality\x12\r\n\tUNDEFINED\x10\x00\x12\x07\n\x03LOW\x10\x01\x12\x07\n\x03MID\x10\x02\x12\x08\n\x04HIGH\x10\x03"\xa2\'\n\x07Message\x12\x14\n\x0c\x63onversation\x18\x01 \x01(\t\x12U\n\x1csenderKeyDistributionMessage\x18\x02 \x01(\x0b\x32/.WAWebProtobufsE2E.SenderKeyDistributionMessage\x12\x35\n\x0cimageMessage\x18\x03 \x01(\x0b\x32\x1f.WAWebProtobufsE2E.ImageMessage\x12\x39\n\x0e\x63ontactMessage\x18\x04 \x01(\x0b\x32!.WAWebProtobufsE2E.ContactMessage\x12;\n\x0flocationMessage\x18\x05 \x01(\x0b\x32".WAWebProtobufsE2E.LocationMessage\x12\x43\n\x13\x65xtendedTextMessage\x18\x06 \x01(\x0b\x32&.WAWebProtobufsE2E.ExtendedTextMessage\x12;\n\x0f\x64ocumentMessage\x18\x07 \x01(\x0b\x32".WAWebProtobufsE2E.DocumentMessage\x12\x35\n\x0c\x61udioMessage\x18\x08 \x01(\x0b\x32\x1f.WAWebProtobufsE2E.AudioMessage\x12\x35\n\x0cvideoMessage\x18\t \x01(\x0b\x32\x1f.WAWebProtobufsE2E.VideoMessage\x12%\n\x04\x63\x61ll\x18\n \x01(\x0b\x32\x17.WAWebProtobufsE2E.Call\x12%\n\x04\x63hat\x18\x0b \x01(\x0b\x32\x17.WAWebProtobufsE2E.Chat\x12;\n\x0fprotocolMessage\x18\x0c \x01(\x0b\x32".WAWebProtobufsE2E.ProtocolMessage\x12\x45\n\x14\x63ontactsArrayMessage\x18\r \x01(\x0b\x32\'.WAWebProtobufsE2E.ContactsArrayMessage\x12K\n\x17highlyStructuredMessage\x18\x0e \x01(\x0b\x32*.WAWebProtobufsE2E.HighlyStructuredMessage\x12\x63\n*fastRatchetKeySenderKeyDistributionMessage\x18\x0f \x01(\x0b\x32/.WAWebProtobufsE2E.SenderKeyDistributionMessage\x12\x41\n\x12sendPaymentMessage\x18\x10 \x01(\x0b\x32%.WAWebProtobufsE2E.SendPaymentMessage\x12\x43\n\x13liveLocationMessage\x18\x12 \x01(\x0b\x32&.WAWebProtobufsE2E.LiveLocationMessage\x12G\n\x15requestPaymentMessage\x18\x16 \x01(\x0b\x32(.WAWebProtobufsE2E.RequestPaymentMessage\x12U\n\x1c\x64\x65\x63linePaymentRequestMessage\x18\x17 \x01(\x0b\x32/.WAWebProtobufsE2E.DeclinePaymentRequestMessage\x12S\n\x1b\x63\x61ncelPaymentRequestMessage\x18\x18 \x01(\x0b\x32..WAWebProtobufsE2E.CancelPaymentRequestMessage\x12;\n\x0ftemplateMessage\x18\x19 \x01(\x0b\x32".WAWebProtobufsE2E.TemplateMessage\x12\x39\n\x0estickerMessage\x18\x1a \x01(\x0b\x32!.WAWebProtobufsE2E.StickerMessage\x12\x41\n\x12groupInviteMessage\x18\x1c \x01(\x0b\x32%.WAWebProtobufsE2E.GroupInviteMessage\x12Q\n\x1atemplateButtonReplyMessage\x18\x1d \x01(\x0b\x32-.WAWebProtobufsE2E.TemplateButtonReplyMessage\x12\x39\n\x0eproductMessage\x18\x1e \x01(\x0b\x32!.WAWebProtobufsE2E.ProductMessage\x12?\n\x11\x64\x65viceSentMessage\x18\x1f \x01(\x0b\x32$.WAWebProtobufsE2E.DeviceSentMessage\x12\x41\n\x12messageContextInfo\x18# \x01(\x0b\x32%.WAWebProtobufsE2E.MessageContextInfo\x12\x33\n\x0blistMessage\x18$ \x01(\x0b\x32\x1e.WAWebProtobufsE2E.ListMessage\x12>\n\x0fviewOnceMessage\x18% \x01(\x0b\x32%.WAWebProtobufsE2E.FutureProofMessage\x12\x35\n\x0corderMessage\x18& \x01(\x0b\x32\x1f.WAWebProtobufsE2E.OrderMessage\x12\x43\n\x13listResponseMessage\x18\' \x01(\x0b\x32&.WAWebProtobufsE2E.ListResponseMessage\x12?\n\x10\x65phemeralMessage\x18( \x01(\x0b\x32%.WAWebProtobufsE2E.FutureProofMessage\x12\x39\n\x0einvoiceMessage\x18) \x01(\x0b\x32!.WAWebProtobufsE2E.InvoiceMessage\x12\x39\n\x0e\x62uttonsMessage\x18* \x01(\x0b\x32!.WAWebProtobufsE2E.ButtonsMessage\x12I\n\x16\x62uttonsResponseMessage\x18+ \x01(\x0b\x32).WAWebProtobufsE2E.ButtonsResponseMessage\x12\x45\n\x14paymentInviteMessage\x18, \x01(\x0b\x32\'.WAWebProtobufsE2E.PaymentInviteMessage\x12\x41\n\x12interactiveMessage\x18- \x01(\x0b\x32%.WAWebProtobufsE2E.InteractiveMessage\x12;\n\x0freactionMessage\x18. \x01(\x0b\x32".WAWebProtobufsE2E.ReactionMessage\x12G\n\x15stickerSyncRmrMessage\x18/ \x01(\x0b\x32(.WAWebProtobufsE2E.StickerSyncRMRMessage\x12Q\n\x1ainteractiveResponseMessage\x18\x30 \x01(\x0b\x32-.WAWebProtobufsE2E.InteractiveResponseMessage\x12\x43\n\x13pollCreationMessage\x18\x31 \x01(\x0b\x32&.WAWebProtobufsE2E.PollCreationMessage\x12?\n\x11pollUpdateMessage\x18\x32 \x01(\x0b\x32$.WAWebProtobufsE2E.PollUpdateMessage\x12?\n\x11keepInChatMessage\x18\x33 \x01(\x0b\x32$.WAWebProtobufsE2E.KeepInChatMessage\x12I\n\x1a\x64ocumentWithCaptionMessage\x18\x35 \x01(\x0b\x32%.WAWebProtobufsE2E.FutureProofMessage\x12O\n\x19requestPhoneNumberMessage\x18\x36 \x01(\x0b\x32,.WAWebProtobufsE2E.RequestPhoneNumberMessage\x12@\n\x11viewOnceMessageV2\x18\x37 \x01(\x0b\x32%.WAWebProtobufsE2E.FutureProofMessage\x12\x41\n\x12\x65ncReactionMessage\x18\x38 \x01(\x0b\x32%.WAWebProtobufsE2E.EncReactionMessage\x12<\n\reditedMessage\x18: \x01(\x0b\x32%.WAWebProtobufsE2E.FutureProofMessage\x12I\n\x1aviewOnceMessageV2Extension\x18; \x01(\x0b\x32%.WAWebProtobufsE2E.FutureProofMessage\x12\x45\n\x15pollCreationMessageV2\x18< \x01(\x0b\x32&.WAWebProtobufsE2E.PollCreationMessage\x12U\n\x1cscheduledCallCreationMessage\x18= \x01(\x0b\x32/.WAWebProtobufsE2E.ScheduledCallCreationMessage\x12\x44\n\x15groupMentionedMessage\x18> \x01(\x0b\x32%.WAWebProtobufsE2E.FutureProofMessage\x12=\n\x10pinInChatMessage\x18? \x01(\x0b\x32#.WAWebProtobufsE2E.PinInChatMessage\x12\x45\n\x15pollCreationMessageV3\x18@ \x01(\x0b\x32&.WAWebProtobufsE2E.PollCreationMessage\x12M\n\x18scheduledCallEditMessage\x18\x41 \x01(\x0b\x32+.WAWebProtobufsE2E.ScheduledCallEditMessage\x12\x33\n\nptvMessage\x18\x42 \x01(\x0b\x32\x1f.WAWebProtobufsE2E.VideoMessage\x12?\n\x10\x62otInvokeMessage\x18\x43 \x01(\x0b\x32%.WAWebProtobufsE2E.FutureProofMessage\x12:\n\x0f\x63\x61llLogMesssage\x18\x45 \x01(\x0b\x32!.WAWebProtobufsE2E.CallLogMessage\x12\x45\n\x14messageHistoryBundle\x18\x46 \x01(\x0b\x32\'.WAWebProtobufsE2E.MessageHistoryBundle\x12?\n\x11\x65ncCommentMessage\x18G \x01(\x0b\x32$.WAWebProtobufsE2E.EncCommentMessage\x12\x35\n\x0c\x62\x63\x61llMessage\x18H \x01(\x0b\x32\x1f.WAWebProtobufsE2E.BCallMessage\x12\x43\n\x14lottieStickerMessage\x18J \x01(\x0b\x32%.WAWebProtobufsE2E.FutureProofMessage\x12\x35\n\x0c\x65ventMessage\x18K \x01(\x0b\x32\x1f.WAWebProtobufsE2E.EventMessage\x12K\n\x17\x65ncEventResponseMessage\x18L \x01(\x0b\x32*.WAWebProtobufsE2E.EncEventResponseMessage\x12\x39\n\x0e\x63ommentMessage\x18M \x01(\x0b\x32!.WAWebProtobufsE2E.CommentMessage\x12U\n\x1cnewsletterAdminInviteMessage\x18N \x01(\x0b\x32/.WAWebProtobufsE2E.NewsletterAdminInviteMessage\x12\x41\n\x12placeholderMessage\x18P \x01(\x0b\x32%.WAWebProtobufsE2E.PlaceholderMessage\x12I\n\x16secretEncryptedMessage\x18R \x01(\x0b\x32).WAWebProtobufsE2E.SecretEncryptedMessage\x12\x35\n\x0c\x61lbumMessage\x18S \x01(\x0b\x32\x1f.WAWebProtobufsE2E.AlbumMessage\x12>\n\x0f\x65ventCoverImage\x18U \x01(\x0b\x32%.WAWebProtobufsE2E.FutureProofMessage\x12\x41\n\x12stickerPackMessage\x18V \x01(\x0b\x32%.WAWebProtobufsE2E.StickerPackMessage\x12\x43\n\x14statusMentionMessage\x18W \x01(\x0b\x32%.WAWebProtobufsE2E.FutureProofMessage\x12O\n\x19pollResultSnapshotMessage\x18X \x01(\x0b\x32,.WAWebProtobufsE2E.PollResultSnapshotMessage\x12\x44\n\x15pollCreationMessageV4\x18Y \x01(\x0b\x32%.WAWebProtobufsE2E.FutureProofMessage\x12M\n\x1epollCreationOptionImageMessage\x18Z \x01(\x0b\x32%.WAWebProtobufsE2E.FutureProofMessage"{\n\x0c\x41lbumMessage\x12\x1a\n\x12\x65xpectedImageCount\x18\x02 \x01(\r\x12\x1a\n\x12\x65xpectedVideoCount\x18\x03 \x01(\r\x12\x33\n\x0b\x63ontextInfo\x18\x11 \x01(\x0b\x32\x1e.WAWebProtobufsE2E.ContextInfo"\xdf\x01\n\x14MessageHistoryBundle\x12\x10\n\x08mimetype\x18\x02 \x01(\t\x12\x12\n\nfileSHA256\x18\x03 \x01(\x0c\x12\x10\n\x08mediaKey\x18\x05 \x01(\x0c\x12\x15\n\rfileEncSHA256\x18\x06 \x01(\x0c\x12\x12\n\ndirectPath\x18\x07 \x01(\t\x12\x19\n\x11mediaKeyTimestamp\x18\x08 \x01(\x03\x12\x33\n\x0b\x63ontextInfo\x18\t \x01(\x0b\x32\x1e.WAWebProtobufsE2E.ContextInfo\x12\x14\n\x0cparticipants\x18\n \x03(\t"s\n\x17\x45ncEventResponseMessage\x12\x35\n\x17\x65ventCreationMessageKey\x18\x01 \x01(\x0b\x32\x14.WACommon.MessageKey\x12\x12\n\nencPayload\x18\x02 \x01(\x0c\x12\r\n\x05\x65ncIV\x18\x03 \x01(\x0c"\x82\x02\n\x0c\x45ventMessage\x12\x33\n\x0b\x63ontextInfo\x18\x01 \x01(\x0b\x32\x1e.WAWebProtobufsE2E.ContextInfo\x12\x12\n\nisCanceled\x18\x02 \x01(\x08\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x34\n\x08location\x18\x05 \x01(\x0b\x32".WAWebProtobufsE2E.LocationMessage\x12\x10\n\x08joinLink\x18\x06 \x01(\t\x12\x11\n\tstartTime\x18\x07 \x01(\x03\x12\x0f\n\x07\x65ndTime\x18\x08 \x01(\x03\x12\x1a\n\x12\x65xtraGuestsAllowed\x18\t \x01(\x08"m\n\x0e\x43ommentMessage\x12+\n\x07message\x18\x01 \x01(\x0b\x32\x1a.WAWebProtobufsE2E.Message\x12.\n\x10targetMessageKey\x18\x02 \x01(\x0b\x32\x14.WACommon.MessageKey"f\n\x11\x45ncCommentMessage\x12.\n\x10targetMessageKey\x18\x01 \x01(\x0b\x32\x14.WACommon.MessageKey\x12\x12\n\nencPayload\x18\x02 \x01(\x0c\x12\r\n\x05\x65ncIV\x18\x03 \x01(\x0c"g\n\x12\x45ncReactionMessage\x12.\n\x10targetMessageKey\x18\x01 \x01(\x0b\x32\x14.WACommon.MessageKey\x12\x12\n\nencPayload\x18\x02 \x01(\x0c\x12\r\n\x05\x65ncIV\x18\x03 \x01(\x0c"z\n\x11KeepInChatMessage\x12!\n\x03key\x18\x01 \x01(\x0b\x32\x14.WACommon.MessageKey\x12-\n\x08keepType\x18\x02 \x01(\x0e\x32\x1b.WAWebProtobufsE2E.KeepType\x12\x13\n\x0btimestampMS\x18\x03 \x01(\x03"\xe1\x01\n\x19PollResultSnapshotMessage\x12\x0c\n\x04name\x18\x01 \x01(\t\x12H\n\tpollVotes\x18\x02 \x03(\x0b\x32\x35.WAWebProtobufsE2E.PollResultSnapshotMessage.PollVote\x12\x33\n\x0b\x63ontextInfo\x18\x03 \x01(\x0b\x32\x1e.WAWebProtobufsE2E.ContextInfo\x1a\x37\n\x08PollVote\x12\x12\n\noptionName\x18\x01 \x01(\t\x12\x17\n\x0foptionVoteCount\x18\x02 \x01(\x03"*\n\x0fPollVoteMessage\x12\x17\n\x0fselectedOptions\x18\x01 \x03(\x0c"1\n\x0cPollEncValue\x12\x12\n\nencPayload\x18\x01 \x01(\x0c\x12\r\n\x05\x65ncIV\x18\x02 \x01(\x0c"\x1b\n\x19PollUpdateMessageMetadata"\xd3\x01\n\x11PollUpdateMessage\x12\x34\n\x16pollCreationMessageKey\x18\x01 \x01(\x0b\x32\x14.WACommon.MessageKey\x12-\n\x04vote\x18\x02 \x01(\x0b\x32\x1f.WAWebProtobufsE2E.PollEncValue\x12>\n\x08metadata\x18\x03 \x01(\x0b\x32,.WAWebProtobufsE2E.PollUpdateMessageMetadata\x12\x19\n\x11senderTimestampMS\x18\x04 \x01(\x03"\xa9\x02\n\x13PollCreationMessage\x12\x0e\n\x06\x65ncKey\x18\x01 \x01(\x0c\x12\x0c\n\x04name\x18\x02 \x01(\t\x12>\n\x07options\x18\x03 \x03(\x0b\x32-.WAWebProtobufsE2E.PollCreationMessage.Option\x12\x1e\n\x16selectableOptionsCount\x18\x04 \x01(\r\x12\x33\n\x0b\x63ontextInfo\x18\x05 \x01(\x0b\x32\x1e.WAWebProtobufsE2E.ContextInfo\x12-\n\x08pollType\x18\x06 \x01(\x0e\x32\x1b.WAWebProtobufsE2E.PollType\x1a\x30\n\x06Option\x12\x12\n\noptionName\x18\x01 \x01(\t\x12\x12\n\noptionHash\x18\x02 \x01(\t"V\n\x15StickerSyncRMRMessage\x12\x10\n\x08\x66ilehash\x18\x01 \x03(\t\x12\x11\n\trmrSource\x18\x02 \x01(\t\x12\x18\n\x10requestTimestamp\x18\x03 \x01(\x03"r\n\x0fReactionMessage\x12!\n\x03key\x18\x01 \x01(\x0b\x32\x14.WACommon.MessageKey\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x13\n\x0bgroupingKey\x18\x03 \x01(\t\x12\x19\n\x11senderTimestampMS\x18\x04 \x01(\x03"A\n\x12\x46utureProofMessage\x12+\n\x07message\x18\x01 \x01(\x0b\x32\x1a.WAWebProtobufsE2E.Message"g\n\x11\x44\x65viceSentMessage\x12\x16\n\x0e\x64\x65stinationJID\x18\x01 \x01(\t\x12+\n\x07message\x18\x02 \x01(\x0b\x32\x1a.WAWebProtobufsE2E.Message\x12\r\n\x05phash\x18\x03 \x01(\t"P\n\x19RequestPhoneNumberMessage\x12\x33\n\x0b\x63ontextInfo\x18\x01 \x01(\x0b\x32\x1e.WAWebProtobufsE2E.ContextInfo"\xc4\x01\n\x1cNewsletterAdminInviteMessage\x12\x15\n\rnewsletterJID\x18\x01 \x01(\t\x12\x16\n\x0enewsletterName\x18\x02 \x01(\t\x12\x15\n\rJPEGThumbnail\x18\x03 \x01(\x0c\x12\x0f\n\x07\x63\x61ption\x18\x04 \x01(\t\x12\x18\n\x10inviteExpiration\x18\x05 \x01(\x03\x12\x33\n\x0b\x63ontextInfo\x18\x06 \x01(\x0b\x32\x1e.WAWebProtobufsE2E.ContextInfo"\x93\x05\n\x0eProductMessage\x12\x42\n\x07product\x18\x01 \x01(\x0b\x32\x31.WAWebProtobufsE2E.ProductMessage.ProductSnapshot\x12\x18\n\x10\x62usinessOwnerJID\x18\x02 \x01(\t\x12\x42\n\x07\x63\x61talog\x18\x04 \x01(\x0b\x32\x31.WAWebProtobufsE2E.ProductMessage.CatalogSnapshot\x12\x0c\n\x04\x62ody\x18\x05 \x01(\t\x12\x0e\n\x06\x66ooter\x18\x06 \x01(\t\x12\x33\n\x0b\x63ontextInfo\x18\x11 \x01(\x0b\x32\x1e.WAWebProtobufsE2E.ContextInfo\x1a\x9d\x02\n\x0fProductSnapshot\x12\x35\n\x0cproductImage\x18\x01 \x01(\x0b\x32\x1f.WAWebProtobufsE2E.ImageMessage\x12\x11\n\tproductID\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x14\n\x0c\x63urrencyCode\x18\x05 \x01(\t\x12\x17\n\x0fpriceAmount1000\x18\x06 \x01(\x03\x12\x12\n\nretailerID\x18\x07 \x01(\t\x12\x0b\n\x03URL\x18\x08 \x01(\t\x12\x19\n\x11productImageCount\x18\t \x01(\r\x12\x14\n\x0c\x66irstImageID\x18\x0b \x01(\t\x12\x1b\n\x13salePriceAmount1000\x18\x0c \x01(\x03\x1al\n\x0f\x43\x61talogSnapshot\x12\x35\n\x0c\x63\x61talogImage\x18\x01 \x01(\x0b\x32\x1f.WAWebProtobufsE2E.ImageMessage\x12\r\n\x05title\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t"\xbc\x01\n\x1aTemplateButtonReplyMessage\x12\x12\n\nselectedID\x18\x01 \x01(\t\x12\x1b\n\x13selectedDisplayText\x18\x02 \x01(\t\x12\x33\n\x0b\x63ontextInfo\x18\x03 \x01(\x0b\x32\x1e.WAWebProtobufsE2E.ContextInfo\x12\x15\n\rselectedIndex\x18\x04 \x01(\r\x12!\n\x19selectedCarouselCardIndex\x18\x05 \x01(\r"\x9c\x0b\n\x0fTemplateMessage\x12M\n\x0f\x66ourRowTemplate\x18\x01 \x01(\x0b\x32\x32.WAWebProtobufsE2E.TemplateMessage.FourRowTemplateH\x00\x12]\n\x17hydratedFourRowTemplate\x18\x02 \x01(\x0b\x32:.WAWebProtobufsE2E.TemplateMessage.HydratedFourRowTemplateH\x00\x12K\n\x1ainteractiveMessageTemplate\x18\x05 \x01(\x0b\x32%.WAWebProtobufsE2E.InteractiveMessageH\x00\x12\x33\n\x0b\x63ontextInfo\x18\x03 \x01(\x0b\x32\x1e.WAWebProtobufsE2E.ContextInfo\x12T\n\x10hydratedTemplate\x18\x04 \x01(\x0b\x32:.WAWebProtobufsE2E.TemplateMessage.HydratedFourRowTemplate\x12\x12\n\ntemplateID\x18\t \x01(\t\x1a\xdb\x03\n\x17HydratedFourRowTemplate\x12=\n\x0f\x64ocumentMessage\x18\x01 \x01(\x0b\x32".WAWebProtobufsE2E.DocumentMessageH\x00\x12\x1b\n\x11hydratedTitleText\x18\x02 \x01(\tH\x00\x12\x37\n\x0cimageMessage\x18\x03 \x01(\x0b\x32\x1f.WAWebProtobufsE2E.ImageMessageH\x00\x12\x37\n\x0cvideoMessage\x18\x04 \x01(\x0b\x32\x1f.WAWebProtobufsE2E.VideoMessageH\x00\x12=\n\x0flocationMessage\x18\x05 \x01(\x0b\x32".WAWebProtobufsE2E.LocationMessageH\x00\x12\x1b\n\x13hydratedContentText\x18\x06 \x01(\t\x12\x1a\n\x12hydratedFooterText\x18\x07 \x01(\t\x12\x42\n\x0fhydratedButtons\x18\x08 \x03(\x0b\x32).WAWebProtobufsE2E.HydratedTemplateButton\x12\x12\n\ntemplateID\x18\t \x01(\t\x12\x19\n\x11maskLinkedDevices\x18\n \x01(\x08\x42\x07\n\x05title\x1a\x86\x04\n\x0f\x46ourRowTemplate\x12=\n\x0f\x64ocumentMessage\x18\x01 \x01(\x0b\x32".WAWebProtobufsE2E.DocumentMessageH\x00\x12M\n\x17highlyStructuredMessage\x18\x02 \x01(\x0b\x32*.WAWebProtobufsE2E.HighlyStructuredMessageH\x00\x12\x37\n\x0cimageMessage\x18\x03 \x01(\x0b\x32\x1f.WAWebProtobufsE2E.ImageMessageH\x00\x12\x37\n\x0cvideoMessage\x18\x04 \x01(\x0b\x32\x1f.WAWebProtobufsE2E.VideoMessageH\x00\x12=\n\x0flocationMessage\x18\x05 \x01(\x0b\x32".WAWebProtobufsE2E.LocationMessageH\x00\x12;\n\x07\x63ontent\x18\x06 \x01(\x0b\x32*.WAWebProtobufsE2E.HighlyStructuredMessage\x12:\n\x06\x66ooter\x18\x07 \x01(\x0b\x32*.WAWebProtobufsE2E.HighlyStructuredMessage\x12\x32\n\x07\x62uttons\x18\x08 \x03(\x0b\x32!.WAWebProtobufsE2E.TemplateButtonB\x07\n\x05titleB\x08\n\x06\x66ormat"\xce\x03\n\x0eStickerMessage\x12\x0b\n\x03URL\x18\x01 \x01(\t\x12\x12\n\nfileSHA256\x18\x02 \x01(\x0c\x12\x15\n\rfileEncSHA256\x18\x03 \x01(\x0c\x12\x10\n\x08mediaKey\x18\x04 \x01(\x0c\x12\x10\n\x08mimetype\x18\x05 \x01(\t\x12\x0e\n\x06height\x18\x06 \x01(\r\x12\r\n\x05width\x18\x07 \x01(\r\x12\x12\n\ndirectPath\x18\x08 \x01(\t\x12\x12\n\nfileLength\x18\t \x01(\x04\x12\x19\n\x11mediaKeyTimestamp\x18\n \x01(\x03\x12\x18\n\x10\x66irstFrameLength\x18\x0b \x01(\r\x12\x19\n\x11\x66irstFrameSidecar\x18\x0c \x01(\x0c\x12\x12\n\nisAnimated\x18\r \x01(\x08\x12\x14\n\x0cpngThumbnail\x18\x10 \x01(\x0c\x12\x33\n\x0b\x63ontextInfo\x18\x11 \x01(\x0b\x32\x1e.WAWebProtobufsE2E.ContextInfo\x12\x15\n\rstickerSentTS\x18\x12 \x01(\x03\x12\x10\n\x08isAvatar\x18\x13 \x01(\x08\x12\x13\n\x0bisAiSticker\x18\x14 \x01(\x08\x12\x10\n\x08isLottie\x18\x15 \x01(\x08\x12\x1a\n\x12\x61\x63\x63\x65ssibilityLabel\x18\x16 \x01(\t"\xaa\x02\n\x13LiveLocationMessage\x12\x17\n\x0f\x64\x65greesLatitude\x18\x01 \x01(\x01\x12\x18\n\x10\x64\x65greesLongitude\x18\x02 \x01(\x01\x12\x18\n\x10\x61\x63\x63uracyInMeters\x18\x03 \x01(\r\x12\x12\n\nspeedInMps\x18\x04 \x01(\x02\x12)\n!degreesClockwiseFromMagneticNorth\x18\x05 \x01(\r\x12\x0f\n\x07\x63\x61ption\x18\x06 \x01(\t\x12\x16\n\x0esequenceNumber\x18\x07 \x01(\x03\x12\x12\n\ntimeOffset\x18\x08 \x01(\r\x12\x15\n\rJPEGThumbnail\x18\x10 \x01(\x0c\x12\x33\n\x0b\x63ontextInfo\x18\x11 \x01(\x0b\x32\x1e.WAWebProtobufsE2E.ContextInfo"@\n\x1b\x43\x61ncelPaymentRequestMessage\x12!\n\x03key\x18\x01 \x01(\x0b\x32\x14.WACommon.MessageKey"A\n\x1c\x44\x65\x63linePaymentRequestMessage\x12!\n\x03key\x18\x01 \x01(\x0b\x32\x14.WACommon.MessageKey"\x8b\x02\n\x15RequestPaymentMessage\x12/\n\x0bnoteMessage\x18\x04 \x01(\x0b\x32\x1a.WAWebProtobufsE2E.Message\x12\x1b\n\x13\x63urrencyCodeIso4217\x18\x01 \x01(\t\x12\x12\n\namount1000\x18\x02 \x01(\x04\x12\x13\n\x0brequestFrom\x18\x03 \x01(\t\x12\x17\n\x0f\x65xpiryTimestamp\x18\x05 \x01(\x03\x12(\n\x06\x61mount\x18\x06 \x01(\x0b\x32\x18.WAWebProtobufsE2E.Money\x12\x38\n\nbackground\x18\x07 \x01(\x0b\x32$.WAWebProtobufsE2E.PaymentBackground"\xb0\x01\n\x12SendPaymentMessage\x12/\n\x0bnoteMessage\x18\x02 \x01(\x0b\x32\x1a.WAWebProtobufsE2E.Message\x12/\n\x11requestMessageKey\x18\x03 \x01(\x0b\x32\x14.WACommon.MessageKey\x12\x38\n\nbackground\x18\x04 \x01(\x0b\x32$.WAWebProtobufsE2E.PaymentBackground"\x95\x01\n\x14\x43ontactsArrayMessage\x12\x13\n\x0b\x64isplayName\x18\x01 \x01(\t\x12\x33\n\x08\x63ontacts\x18\x02 \x03(\x0b\x32!.WAWebProtobufsE2E.ContactMessage\x12\x33\n\x0b\x63ontextInfo\x18\x11 \x01(\x0b\x32\x1e.WAWebProtobufsE2E.ContextInfo"M\n&InitialSecurityNotificationSettingSync\x12#\n\x1bsecurityNotificationEnabled\x18\x01 \x01(\x08"\xdf\t\n\x1fPeerDataOperationRequestMessage\x12U\n\x1cpeerDataOperationRequestType\x18\x01 \x01(\x0e\x32/.WAWebProtobufsE2E.PeerDataOperationRequestType\x12i\n\x16requestStickerReupload\x18\x02 \x03(\x0b\x32I.WAWebProtobufsE2E.PeerDataOperationRequestMessage.RequestStickerReupload\x12_\n\x11requestURLPreview\x18\x03 \x03(\x0b\x32\x44.WAWebProtobufsE2E.PeerDataOperationRequestMessage.RequestUrlPreview\x12q\n\x1ahistorySyncOnDemandRequest\x18\x04 \x01(\x0b\x32M.WAWebProtobufsE2E.PeerDataOperationRequestMessage.HistorySyncOnDemandRequest\x12{\n\x1fplaceholderMessageResendRequest\x18\x05 \x03(\x0b\x32R.WAWebProtobufsE2E.PeerDataOperationRequestMessage.PlaceholderMessageResendRequest\x12y\n\x1e\x66ullHistorySyncOnDemandRequest\x18\x06 \x01(\x0b\x32Q.WAWebProtobufsE2E.PeerDataOperationRequestMessage.FullHistorySyncOnDemandRequest\x1aK\n\x1fPlaceholderMessageResendRequest\x12(\n\nmessageKey\x18\x01 \x01(\x0b\x32\x14.WACommon.MessageKey\x1a\xca\x01\n\x1e\x46ullHistorySyncOnDemandRequest\x12R\n\x0frequestMetadata\x18\x01 \x01(\x0b\x32\x39.WAWebProtobufsE2E.FullHistorySyncOnDemandRequestMetadata\x12T\n\x11historySyncConfig\x18\x02 \x01(\x0b\x32\x39.WAWebProtobufsCompanionReg.DeviceProps.HistorySyncConfig\x1a\xa7\x01\n\x1aHistorySyncOnDemandRequest\x12\x0f\n\x07\x63hatJID\x18\x01 \x01(\t\x12\x13\n\x0boldestMsgID\x18\x02 \x01(\t\x12\x17\n\x0foldestMsgFromMe\x18\x03 \x01(\x08\x12\x18\n\x10onDemandMsgCount\x18\x04 \x01(\x05\x12\x1c\n\x14oldestMsgTimestampMS\x18\x05 \x01(\x03\x12\x12\n\naccountLid\x18\x06 \x01(\t\x1a<\n\x11RequestUrlPreview\x12\x0b\n\x03URL\x18\x01 \x01(\t\x12\x1a\n\x12includeHqThumbnail\x18\x02 \x01(\x08\x1a,\n\x16RequestStickerReupload\x12\x12\n\nfileSHA256\x18\x01 \x01(\t";\n&FullHistorySyncOnDemandRequestMetadata\x12\x11\n\trequestID\x18\x01 \x01(\t"P\n"AppStateFatalExceptionNotification\x12\x17\n\x0f\x63ollectionNames\x18\x01 \x03(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\x03"N\n\x16\x41ppStateSyncKeyRequest\x12\x34\n\x06keyIDs\x18\x01 \x03(\x0b\x32$.WAWebProtobufsE2E.AppStateSyncKeyId"H\n\x14\x41ppStateSyncKeyShare\x12\x30\n\x04keys\x18\x01 \x03(\x0b\x32".WAWebProtobufsE2E.AppStateSyncKey"}\n\x13\x41ppStateSyncKeyData\x12\x0f\n\x07keyData\x18\x01 \x01(\x0c\x12\x42\n\x0b\x66ingerprint\x18\x02 \x01(\x0b\x32-.WAWebProtobufsE2E.AppStateSyncKeyFingerprint\x12\x11\n\ttimestamp\x18\x03 \x01(\x03"\\\n\x1a\x41ppStateSyncKeyFingerprint\x12\r\n\x05rawID\x18\x01 \x01(\r\x12\x14\n\x0c\x63urrentIndex\x18\x02 \x01(\r\x12\x19\n\rdeviceIndexes\x18\x03 \x03(\rB\x02\x10\x01""\n\x11\x41ppStateSyncKeyId\x12\r\n\x05keyID\x18\x01 \x01(\x0c"\x7f\n\x0f\x41ppStateSyncKey\x12\x33\n\x05keyID\x18\x01 \x01(\x0b\x32$.WAWebProtobufsE2E.AppStateSyncKeyId\x12\x37\n\x07keyData\x18\x02 \x01(\x0b\x32&.WAWebProtobufsE2E.AppStateSyncKeyData"\'\n\x04\x43hat\x12\x13\n\x0b\x64isplayName\x18\x01 \x01(\t\x12\n\n\x02ID\x18\x02 \x01(\t"\x93\x01\n\x04\x43\x61ll\x12\x0f\n\x07\x63\x61llKey\x18\x01 \x01(\x0c\x12\x18\n\x10\x63onversionSource\x18\x02 \x01(\t\x12\x16\n\x0e\x63onversionData\x18\x03 \x01(\x0c\x12\x1e\n\x16\x63onversionDelaySeconds\x18\x04 \x01(\r\x12\x13\n\x0b\x63twaSignals\x18\x05 \x01(\t\x12\x13\n\x0b\x63twaPayload\x18\x06 \x01(\x0c"\xf2\x02\n\x0c\x41udioMessage\x12\x0b\n\x03URL\x18\x01 \x01(\t\x12\x10\n\x08mimetype\x18\x02 \x01(\t\x12\x12\n\nfileSHA256\x18\x03 \x01(\x0c\x12\x12\n\nfileLength\x18\x04 \x01(\x04\x12\x0f\n\x07seconds\x18\x05 \x01(\r\x12\x0b\n\x03PTT\x18\x06 \x01(\x08\x12\x10\n\x08mediaKey\x18\x07 \x01(\x0c\x12\x15\n\rfileEncSHA256\x18\x08 \x01(\x0c\x12\x12\n\ndirectPath\x18\t \x01(\t\x12\x19\n\x11mediaKeyTimestamp\x18\n \x01(\x03\x12\x33\n\x0b\x63ontextInfo\x18\x11 \x01(\x0b\x32\x1e.WAWebProtobufsE2E.ContextInfo\x12\x18\n\x10streamingSidecar\x18\x12 \x01(\x0c\x12\x10\n\x08waveform\x18\x13 \x01(\x0c\x12\x16\n\x0e\x62\x61\x63kgroundArgb\x18\x14 \x01(\x07\x12\x10\n\x08viewOnce\x18\x15 \x01(\x08\x12\x1a\n\x12\x61\x63\x63\x65ssibilityLabel\x18\x16 \x01(\t"\xf6\x03\n\x0f\x44ocumentMessage\x12\x0b\n\x03URL\x18\x01 \x01(\t\x12\x10\n\x08mimetype\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x12\n\nfileSHA256\x18\x04 \x01(\x0c\x12\x12\n\nfileLength\x18\x05 \x01(\x04\x12\x11\n\tpageCount\x18\x06 \x01(\r\x12\x10\n\x08mediaKey\x18\x07 \x01(\x0c\x12\x10\n\x08\x66ileName\x18\x08 \x01(\t\x12\x15\n\rfileEncSHA256\x18\t \x01(\x0c\x12\x12\n\ndirectPath\x18\n \x01(\t\x12\x19\n\x11mediaKeyTimestamp\x18\x0b \x01(\x03\x12\x14\n\x0c\x63ontactVcard\x18\x0c \x01(\x08\x12\x1b\n\x13thumbnailDirectPath\x18\r \x01(\t\x12\x17\n\x0fthumbnailSHA256\x18\x0e \x01(\x0c\x12\x1a\n\x12thumbnailEncSHA256\x18\x0f \x01(\x0c\x12\x15\n\rJPEGThumbnail\x18\x10 \x01(\x0c\x12\x33\n\x0b\x63ontextInfo\x18\x11 \x01(\x0b\x32\x1e.WAWebProtobufsE2E.ContextInfo\x12\x17\n\x0fthumbnailHeight\x18\x12 \x01(\r\x12\x16\n\x0ethumbnailWidth\x18\x13 \x01(\r\x12\x0f\n\x07\x63\x61ption\x18\x14 \x01(\t\x12\x1a\n\x12\x61\x63\x63\x65ssibilityLabel\x18\x15 \x01(\t"\xb6\x02\n\x0fLocationMessage\x12\x17\n\x0f\x64\x65greesLatitude\x18\x01 \x01(\x01\x12\x18\n\x10\x64\x65greesLongitude\x18\x02 \x01(\x01\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x04 \x01(\t\x12\x0b\n\x03URL\x18\x05 \x01(\t\x12\x0e\n\x06isLive\x18\x06 \x01(\x08\x12\x18\n\x10\x61\x63\x63uracyInMeters\x18\x07 \x01(\r\x12\x12\n\nspeedInMps\x18\x08 \x01(\x02\x12)\n!degreesClockwiseFromMagneticNorth\x18\t \x01(\r\x12\x0f\n\x07\x63omment\x18\x0b \x01(\t\x12\x15\n\rJPEGThumbnail\x18\x10 \x01(\x0c\x12\x33\n\x0b\x63ontextInfo\x18\x11 \x01(\x0b\x32\x1e.WAWebProtobufsE2E.ContextInfo"i\n\x0e\x43ontactMessage\x12\x13\n\x0b\x64isplayName\x18\x01 \x01(\t\x12\r\n\x05vcard\x18\x10 \x01(\t\x12\x33\n\x0b\x63ontextInfo\x18\x11 \x01(\x0b\x32\x1e.WAWebProtobufsE2E.ContextInfo"\\\n\x1cSenderKeyDistributionMessage\x12\x0f\n\x07groupID\x18\x01 \x01(\t\x12+\n#axolotlSenderKeyDistributionMessage\x18\x02 \x01(\x0c"s\n\x11\x42otAvatarMetadata\x12\x11\n\tsentiment\x18\x01 \x01(\r\x12\x15\n\rbehaviorGraph\x18\x02 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x03 \x01(\r\x12\x11\n\tintensity\x18\x04 \x01(\r\x12\x11\n\twordCount\x18\x05 \x01(\r"S\n\x1a\x42otSuggestedPromptMetadata\x12\x18\n\x10suggestedPrompts\x18\x01 \x03(\t\x12\x1b\n\x13selectedPromptIndex\x18\x02 \x01(\r"\x95\x01\n\x11\x42otMemoryMetadata\x12\x34\n\naddedFacts\x18\x01 \x03(\x0b\x32 .WAWebProtobufsE2E.BotMemoryFact\x12\x36\n\x0cremovedFacts\x18\x02 \x03(\x0b\x32 .WAWebProtobufsE2E.BotMemoryFact\x12\x12\n\ndisclaimer\x18\x03 \x01(\t"-\n\rBotMemoryFact\x12\x0c\n\x04\x66\x61\x63t\x18\x01 \x01(\t\x12\x0e\n\x06\x66\x61\x63tID\x18\x02 \x01(\t"c\n\x12\x42otSessionMetadata\x12\x11\n\tsessionID\x18\x01 \x01(\t\x12:\n\rsessionSource\x18\x02 \x01(\x0e\x32#.WAWebProtobufsE2E.BotSessionSource"J\n\x0f\x42otMemuMetadata\x12\x37\n\nfaceImages\x18\x01 \x03(\x0b\x32#.WAWebProtobufsE2E.BotMediaMetadata";\n\x1c\x42otProgressIndicatorMetadata\x12\x1b\n\x13progressDescription\x18\x01 \x01(\t"\xc1\x06\n\x0b\x42otMetadata\x12<\n\x0e\x61vatarMetadata\x18\x01 \x01(\x0b\x32$.WAWebProtobufsE2E.BotAvatarMetadata\x12\x11\n\tpersonaID\x18\x02 \x01(\t\x12<\n\x0epluginMetadata\x18\x03 \x01(\x0b\x32$.WAWebProtobufsE2E.BotPluginMetadata\x12N\n\x17suggestedPromptMetadata\x18\x04 \x01(\x0b\x32-.WAWebProtobufsE2E.BotSuggestedPromptMetadata\x12\x12\n\ninvokerJID\x18\x05 \x01(\t\x12>\n\x0fsessionMetadata\x18\x06 \x01(\x0b\x32%.WAWebProtobufsE2E.BotSessionMetadata\x12\x38\n\x0cmemuMetadata\x18\x07 \x01(\x0b\x32".WAWebProtobufsE2E.BotMemuMetadata\x12\x10\n\x08timezone\x18\x08 \x01(\t\x12@\n\x10reminderMetadata\x18\t \x01(\x0b\x32&.WAWebProtobufsE2E.BotReminderMetadata\x12:\n\rmodelMetadata\x18\n \x01(\x0b\x32#.WAWebProtobufsE2E.BotModelMetadata\x12\x1d\n\x15messageDisclaimerText\x18\x0b \x01(\t\x12R\n\x19progressIndicatorMetadata\x18\x0c \x01(\x0b\x32/.WAWebProtobufsE2E.BotProgressIndicatorMetadata\x12\x44\n\x12\x63\x61pabilityMetadata\x18\r \x01(\x0b\x32(.WAWebProtobufsE2E.BotCapabilityMetadata\x12>\n\x0fimagineMetadata\x18\x0e \x01(\x0b\x32%.WAWebProtobufsE2E.BotImagineMetadata\x12<\n\x0ememoryMetadata\x18\x0f \x01(\x0b\x32$.WAWebProtobufsE2E.BotMemoryMetadata"\xa5\x02\n\x12\x44\x65viceListMetadata\x12\x15\n\rsenderKeyHash\x18\x01 \x01(\x0c\x12\x17\n\x0fsenderTimestamp\x18\x02 \x01(\x04\x12\x1c\n\x10senderKeyIndexes\x18\x03 \x03(\rB\x02\x10\x01\x12\x33\n\x11senderAccountType\x18\x04 \x01(\x0e\x32\x18.WAAdv.ADVEncryptionType\x12\x35\n\x13receiverAccountType\x18\x05 \x01(\x0e\x32\x18.WAAdv.ADVEncryptionType\x12\x18\n\x10recipientKeyHash\x18\x08 \x01(\x0c\x12\x1a\n\x12recipientTimestamp\x18\t \x01(\x04\x12\x1f\n\x13recipientKeyIndexes\x18\n \x03(\rB\x02\x10\x01"P\n\x0f\x45mbeddedMessage\x12\x10\n\x08stanzaID\x18\x01 \x01(\t\x12+\n\x07message\x18\x02 \x01(\x0b\x32\x1a.WAWebProtobufsE2E.Message"\x89\x02\n\rEmbeddedMusic\x12\x1b\n\x13musicContentMediaID\x18\x01 \x01(\t\x12\x0e\n\x06songID\x18\x02 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\x12\x19\n\x11\x61rtworkDirectPath\x18\x05 \x01(\t\x12\x15\n\rartworkSHA256\x18\x06 \x01(\x0c\x12\x18\n\x10\x61rtworkEncSHA256\x18\x07 \x01(\x0c\x12\x17\n\x0f\x61rtworkMediaKey\x18\x0b \x01(\x0c\x12\x19\n\x11\x61rtistAttribution\x18\x08 \x01(\t\x12\x18\n\x10\x63ountryBlocklist\x18\t \x01(\x0c\x12\x12\n\nisExplicit\x18\n \x01(\x08"\x96\x01\n\x0f\x45mbeddedContent\x12=\n\x0f\x65mbeddedMessage\x18\x01 \x01(\x0b\x32".WAWebProtobufsE2E.EmbeddedMessageH\x00\x12\x39\n\rembeddedMusic\x18\x02 \x01(\x0b\x32 .WAWebProtobufsE2E.EmbeddedMusicH\x00\x42\t\n\x07\x63ontent".\n\rTapLinkAction\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0e\n\x06tapURL\x18\x02 \x01(\t"\x88\x03\n\x15InteractiveAnnotation\x12/\n\x08location\x18\x02 \x01(\x0b\x32\x1b.WAWebProtobufsE2E.LocationH\x00\x12S\n\nnewsletter\x18\x03 \x01(\x0b\x32=.WAWebProtobufsE2E.ContextInfo.ForwardedNewsletterMessageInfoH\x00\x12\x18\n\x0e\x65mbeddedAction\x18\x06 \x01(\x08H\x00\x12\x35\n\ttapAction\x18\x07 \x01(\x0b\x32 .WAWebProtobufsE2E.TapLinkActionH\x00\x12\x31\n\x0fpolygonVertices\x18\x01 \x03(\x0b\x32\x18.WAWebProtobufsE2E.Point\x12\x1e\n\x16shouldSkipConfirmation\x18\x04 \x01(\x08\x12;\n\x0f\x65mbeddedContent\x18\x05 \x01(\x0b\x32".WAWebProtobufsE2E.EmbeddedContentB\x08\n\x06\x61\x63tion"G\n\x05Point\x12\x13\n\x0bxDeprecated\x18\x01 \x01(\x05\x12\x13\n\x0byDeprecated\x18\x02 \x01(\x05\x12\t\n\x01x\x18\x03 \x01(\x01\x12\t\n\x01y\x18\x04 \x01(\x01"K\n\x08Location\x12\x17\n\x0f\x64\x65greesLatitude\x18\x01 \x01(\x01\x12\x18\n\x10\x64\x65greesLongitude\x18\x02 \x01(\x01\x12\x0c\n\x04name\x18\x03 \x01(\t"\xf9\x04\n\x0eTemplateButton\x12N\n\x10quickReplyButton\x18\x01 \x01(\x0b\x32\x32.WAWebProtobufsE2E.TemplateButton.QuickReplyButtonH\x00\x12@\n\turlButton\x18\x02 \x01(\x0b\x32+.WAWebProtobufsE2E.TemplateButton.URLButtonH\x00\x12\x42\n\ncallButton\x18\x03 \x01(\x0b\x32,.WAWebProtobufsE2E.TemplateButton.CallButtonH\x00\x12\r\n\x05index\x18\x04 \x01(\r\x1a\x8e\x01\n\nCallButton\x12?\n\x0b\x64isplayText\x18\x01 \x01(\x0b\x32*.WAWebProtobufsE2E.HighlyStructuredMessage\x12?\n\x0bphoneNumber\x18\x02 \x01(\x0b\x32*.WAWebProtobufsE2E.HighlyStructuredMessage\x1a\x85\x01\n\tURLButton\x12?\n\x0b\x64isplayText\x18\x01 \x01(\x0b\x32*.WAWebProtobufsE2E.HighlyStructuredMessage\x12\x37\n\x03URL\x18\x02 \x01(\x0b\x32*.WAWebProtobufsE2E.HighlyStructuredMessage\x1a_\n\x10QuickReplyButton\x12?\n\x0b\x64isplayText\x18\x01 \x01(\x0b\x32*.WAWebProtobufsE2E.HighlyStructuredMessage\x12\n\n\x02ID\x18\x02 \x01(\tB\x08\n\x06\x62utton"<\n\x05Money\x12\r\n\x05value\x18\x01 \x01(\x03\x12\x0e\n\x06offset\x18\x02 \x01(\r\x12\x14\n\x0c\x63urrencyCode\x18\x03 \x01(\t".\n\nActionLink\x12\x0b\n\x03URL\x18\x01 \x01(\t\x12\x13\n\x0b\x62uttonTitle\x18\x02 \x01(\t"6\n\x0cGroupMention\x12\x10\n\x08groupJID\x18\x01 \x01(\t\x12\x14\n\x0cgroupSubject\x18\x02 \x01(\t"J\n\x14MessageSecretMessage\x12\x0f\n\x07version\x18\x01 \x01(\x0f\x12\r\n\x05\x65ncIV\x18\x02 \x01(\x0c\x12\x12\n\nencPayload\x18\x03 \x01(\x0c"W\n\x12MediaNotifyMessage\x12\x16\n\x0e\x65xpressPathURL\x18\x01 \x01(\t\x12\x15\n\rfileEncSHA256\x18\x02 \x01(\x0c\x12\x12\n\nfileLength\x18\x03 \x01(\x04"?\n\x1eLIDMigrationMappingSyncMessage\x12\x1d\n\x15\x65ncodedMappingPayload\x18\x01 \x01(\x0c*\x1f\n\x08PollType\x12\x08\n\x04TEXT\x10\x01\x12\t\n\x05IMAGE\x10\x02*\x8d\x02\n\x1cPeerDataOperationRequestType\x12\x12\n\x0eUPLOAD_STICKER\x10\x00\x12!\n\x1dSEND_RECENT_STICKER_BOOTSTRAP\x10\x01\x12\x19\n\x15GENERATE_LINK_PREVIEW\x10\x02\x12\x1a\n\x16HISTORY_SYNC_ON_DEMAND\x10\x03\x12\x1e\n\x1aPLACEHOLDER_MESSAGE_RESEND\x10\x04\x12\x1e\n\x1aWAFFLE_LINKING_NONCE_FETCH\x10\x05\x12\x1f\n\x1b\x46ULL_HISTORY_SYNC_ON_DEMAND\x10\x06\x12\x1e\n\x1a\x43OMPANION_META_NONCE_FETCH\x10\x07*s\n\x10\x42otSessionSource\x12\x0e\n\nNULL_STATE\x10\x01\x12\r\n\tTYPEAHEAD\x10\x02\x12\x0e\n\nUSER_INPUT\x10\x03\x12\r\n\tEMU_FLASH\x10\x04\x12\x16\n\x12\x45MU_FLASH_FOLLOWUP\x10\x05\x12\t\n\x05VOICE\x10\x06*@\n\x08KeepType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x10\n\x0cKEEP_FOR_ALL\x10\x01\x12\x15\n\x11UNDO_KEEP_FOR_ALL\x10\x02\x42!Z\x1fgo.mau.fi/whatsmeow/proto/waE2E'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "waE2E.WAWebProtobufsE2E_pb2", _globals
)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\037go.mau.fi/whatsmeow/proto/waE2E"
    _globals["_APPSTATESYNCKEYFINGERPRINT"].fields_by_name[
        "deviceIndexes"
    ]._options = None
    _globals["_APPSTATESYNCKEYFINGERPRINT"].fields_by_name[
        "deviceIndexes"
    ]._serialized_options = b"\020\001"
    _globals["_DEVICELISTMETADATA"].fields_by_name["senderKeyIndexes"]._options = None
    _globals["_DEVICELISTMETADATA"].fields_by_name[
        "senderKeyIndexes"
    ]._serialized_options = b"\020\001"
    _globals["_DEVICELISTMETADATA"].fields_by_name[
        "recipientKeyIndexes"
    ]._options = None
    _globals["_DEVICELISTMETADATA"].fields_by_name[
        "recipientKeyIndexes"
    ]._serialized_options = b"\020\001"
    _globals["_POLLTYPE"]._serialized_start = 47458
    _globals["_POLLTYPE"]._serialized_end = 47489
    _globals["_PEERDATAOPERATIONREQUESTTYPE"]._serialized_start = 47492
    _globals["_PEERDATAOPERATIONREQUESTTYPE"]._serialized_end = 47761
    _globals["_BOTSESSIONSOURCE"]._serialized_start = 47763
    _globals["_BOTSESSIONSOURCE"]._serialized_end = 47878
    _globals["_KEEPTYPE"]._serialized_start = 47880
    _globals["_KEEPTYPE"]._serialized_end = 47944
    _globals["_STICKERPACKMESSAGE"]._serialized_start = 175
    _globals["_STICKERPACKMESSAGE"]._serialized_end = 1030
    _globals["_STICKERPACKMESSAGE_STICKER"]._serialized_start = 830
    _globals["_STICKERPACKMESSAGE_STICKER"]._serialized_end = 957
    _globals["_STICKERPACKMESSAGE_STICKERPACKORIGIN"]._serialized_start = 959
    _globals["_STICKERPACKMESSAGE_STICKERPACKORIGIN"]._serialized_end = 1030
    _globals["_PLACEHOLDERMESSAGE"]._serialized_start = 1033
    _globals["_PLACEHOLDERMESSAGE"]._serialized_end = 1166
    _globals["_PLACEHOLDERMESSAGE_PLACEHOLDERTYPE"]._serialized_start = 1124
    _globals["_PLACEHOLDERMESSAGE_PLACEHOLDERTYPE"]._serialized_end = 1166
    _globals["_BCALLMESSAGE"]._serialized_start = 1169
    _globals["_BCALLMESSAGE"]._serialized_end = 1348
    _globals["_BCALLMESSAGE_MEDIATYPE"]._serialized_start = 1302
    _globals["_BCALLMESSAGE_MEDIATYPE"]._serialized_end = 1348
    _globals["_CALLLOGMESSAGE"]._serialized_start = 1351
    _globals["_CALLLOGMESSAGE"]._serialized_end = 1926
    _globals["_CALLLOGMESSAGE_CALLPARTICIPANT"]._serialized_start = 1611
    _globals["_CALLLOGMESSAGE_CALLPARTICIPANT"]._serialized_end = 1709
    _globals["_CALLLOGMESSAGE_CALLOUTCOME"]._serialized_start = 1712
    _globals["_CALLLOGMESSAGE_CALLOUTCOME"]._serialized_end = 1865
    _globals["_CALLLOGMESSAGE_CALLTYPE"]._serialized_start = 1867
    _globals["_CALLLOGMESSAGE_CALLTYPE"]._serialized_end = 1926
    _globals["_SCHEDULEDCALLEDITMESSAGE"]._serialized_start = 1929
    _globals["_SCHEDULEDCALLEDITMESSAGE"]._serialized_end = 2099
    _globals["_SCHEDULEDCALLEDITMESSAGE_EDITTYPE"]._serialized_start = 2064
    _globals["_SCHEDULEDCALLEDITMESSAGE_EDITTYPE"]._serialized_end = 2099
    _globals["_SCHEDULEDCALLCREATIONMESSAGE"]._serialized_start = 2102
    _globals["_SCHEDULEDCALLCREATIONMESSAGE"]._serialized_end = 2300
    _globals["_SCHEDULEDCALLCREATIONMESSAGE_CALLTYPE"]._serialized_start = 2255
    _globals["_SCHEDULEDCALLCREATIONMESSAGE_CALLTYPE"]._serialized_end = 2300
    _globals["_EVENTRESPONSEMESSAGE"]._serialized_start = 2303
    _globals["_EVENTRESPONSEMESSAGE"]._serialized_end = 2519
    _globals["_EVENTRESPONSEMESSAGE_EVENTRESPONSETYPE"]._serialized_start = 2450
    _globals["_EVENTRESPONSEMESSAGE_EVENTRESPONSETYPE"]._serialized_end = 2519
    _globals["_PININCHATMESSAGE"]._serialized_start = 2522
    _globals["_PININCHATMESSAGE"]._serialized_end = 2720
    _globals["_PININCHATMESSAGE_TYPE"]._serialized_start = 2660
    _globals["_PININCHATMESSAGE_TYPE"]._serialized_end = 2720
    _globals["_BUTTONSRESPONSEMESSAGE"]._serialized_start = 2723
    _globals["_BUTTONSRESPONSEMESSAGE"]._serialized_end = 2970
    _globals["_BUTTONSRESPONSEMESSAGE_TYPE"]._serialized_start = 2921
    _globals["_BUTTONSRESPONSEMESSAGE_TYPE"]._serialized_end = 2958
    _globals["_BUTTONSMESSAGE"]._serialized_start = 2973
    _globals["_BUTTONSMESSAGE"]._serialized_end = 3955
    _globals["_BUTTONSMESSAGE_BUTTON"]._serialized_start = 3467
    _globals["_BUTTONSMESSAGE_BUTTON"]._serialized_end = 3847
    _globals["_BUTTONSMESSAGE_BUTTON_NATIVEFLOWINFO"]._serialized_start = 3710
    _globals["_BUTTONSMESSAGE_BUTTON_NATIVEFLOWINFO"]._serialized_end = 3760
    _globals["_BUTTONSMESSAGE_BUTTON_BUTTONTEXT"]._serialized_start = 3762
    _globals["_BUTTONSMESSAGE_BUTTON_BUTTONTEXT"]._serialized_end = 3795
    _globals["_BUTTONSMESSAGE_BUTTON_TYPE"]._serialized_start = 3797
    _globals["_BUTTONSMESSAGE_BUTTON_TYPE"]._serialized_end = 3847
    _globals["_BUTTONSMESSAGE_HEADERTYPE"]._serialized_start = 3849
    _globals["_BUTTONSMESSAGE_HEADERTYPE"]._serialized_end = 3945
    _globals["_SECRETENCRYPTEDMESSAGE"]._serialized_start = 3958
    _globals["_SECRETENCRYPTEDMESSAGE"]._serialized_end = 4191
    _globals["_SECRETENCRYPTEDMESSAGE_SECRETENCTYPE"]._serialized_start = 4147
    _globals["_SECRETENCRYPTEDMESSAGE_SECRETENCTYPE"]._serialized_end = 4191
    _globals["_GROUPINVITEMESSAGE"]._serialized_start = 4194
    _globals["_GROUPINVITEMESSAGE"]._serialized_end = 4496
    _globals["_GROUPINVITEMESSAGE_GROUPTYPE"]._serialized_start = 4460
    _globals["_GROUPINVITEMESSAGE_GROUPTYPE"]._serialized_end = 4496
    _globals["_INTERACTIVERESPONSEMESSAGE"]._serialized_start = 4499
    _globals["_INTERACTIVERESPONSEMESSAGE"]._serialized_end = 5005
    _globals["_INTERACTIVERESPONSEMESSAGE_BODY"]._serialized_start = 4759
    _globals["_INTERACTIVERESPONSEMESSAGE_BODY"]._serialized_end = 4895
    _globals["_INTERACTIVERESPONSEMESSAGE_BODY_FORMAT"]._serialized_start = 4856
    _globals["_INTERACTIVERESPONSEMESSAGE_BODY_FORMAT"]._serialized_end = 4895
    _globals[
        "_INTERACTIVERESPONSEMESSAGE_NATIVEFLOWRESPONSEMESSAGE"
    ]._serialized_start = 4897
    _globals[
        "_INTERACTIVERESPONSEMESSAGE_NATIVEFLOWRESPONSEMESSAGE"
    ]._serialized_end = 4975
    _globals["_INTERACTIVEMESSAGE"]._serialized_start = 5008
    _globals["_INTERACTIVEMESSAGE"]._serialized_end = 6654
    _globals["_INTERACTIVEMESSAGE_SHOPMESSAGE"]._serialized_start = 5604
    _globals["_INTERACTIVEMESSAGE_SHOPMESSAGE"]._serialized_end = 5785
    _globals["_INTERACTIVEMESSAGE_SHOPMESSAGE_SURFACE"]._serialized_start = 5731
    _globals["_INTERACTIVEMESSAGE_SHOPMESSAGE_SURFACE"]._serialized_end = 5785
    _globals["_INTERACTIVEMESSAGE_CAROUSELMESSAGE"]._serialized_start = 5787
    _globals["_INTERACTIVEMESSAGE_CAROUSELMESSAGE"]._serialized_end = 5882
    _globals["_INTERACTIVEMESSAGE_NATIVEFLOWMESSAGE"]._serialized_start = 5885
    _globals["_INTERACTIVEMESSAGE_NATIVEFLOWMESSAGE"]._serialized_end = 6106
    _globals[
        "_INTERACTIVEMESSAGE_NATIVEFLOWMESSAGE_NATIVEFLOWBUTTON"
    ]._serialized_start = 6048
    _globals[
        "_INTERACTIVEMESSAGE_NATIVEFLOWMESSAGE_NATIVEFLOWBUTTON"
    ]._serialized_end = 6106
    _globals["_INTERACTIVEMESSAGE_COLLECTIONMESSAGE"]._serialized_start = 6108
    _globals["_INTERACTIVEMESSAGE_COLLECTIONMESSAGE"]._serialized_end = 6179
    _globals["_INTERACTIVEMESSAGE_FOOTER"]._serialized_start = 6181
    _globals["_INTERACTIVEMESSAGE_FOOTER"]._serialized_end = 6203
    _globals["_INTERACTIVEMESSAGE_BODY"]._serialized_start = 4759
    _globals["_INTERACTIVEMESSAGE_BODY"]._serialized_end = 4779
    _globals["_INTERACTIVEMESSAGE_HEADER"]._serialized_start = 6228
    _globals["_INTERACTIVEMESSAGE_HEADER"]._serialized_end = 6632
    _globals["_LISTRESPONSEMESSAGE"]._serialized_start = 6657
    _globals["_LISTRESPONSEMESSAGE"]._serialized_end = 7007
    _globals["_LISTRESPONSEMESSAGE_SINGLESELECTREPLY"]._serialized_start = 6921
    _globals["_LISTRESPONSEMESSAGE_SINGLESELECTREPLY"]._serialized_end = 6963
    _globals["_LISTRESPONSEMESSAGE_LISTTYPE"]._serialized_start = 6965
    _globals["_LISTRESPONSEMESSAGE_LISTTYPE"]._serialized_end = 7007
    _globals["_LISTMESSAGE"]._serialized_start = 7010
    _globals["_LISTMESSAGE"]._serialized_end = 7921
    _globals["_LISTMESSAGE_PRODUCTLISTINFO"]._serialized_start = 7345
    _globals["_LISTMESSAGE_PRODUCTLISTINFO"]._serialized_end = 7536
    _globals["_LISTMESSAGE_PRODUCTLISTHEADERIMAGE"]._serialized_start = 7538
    _globals["_LISTMESSAGE_PRODUCTLISTHEADERIMAGE"]._serialized_end = 7604
    _globals["_LISTMESSAGE_PRODUCTSECTION"]._serialized_start = 7606
    _globals["_LISTMESSAGE_PRODUCTSECTION"]._serialized_end = 7695
    _globals["_LISTMESSAGE_PRODUCT"]._serialized_start = 7697
    _globals["_LISTMESSAGE_PRODUCT"]._serialized_end = 7725
    _globals["_LISTMESSAGE_SECTION"]._serialized_start = 7727
    _globals["_LISTMESSAGE_SECTION"]._serialized_end = 7801
    _globals["_LISTMESSAGE_ROW"]._serialized_start = 7803
    _globals["_LISTMESSAGE_ROW"]._serialized_end = 7859
    _globals["_LISTMESSAGE_LISTTYPE"]._serialized_start = 7861
    _globals["_LISTMESSAGE_LISTTYPE"]._serialized_end = 7921
    _globals["_ORDERMESSAGE"]._serialized_start = 7924
    _globals["_ORDERMESSAGE"]._serialized_end = 8455
    _globals["_ORDERMESSAGE_ORDERSURFACE"]._serialized_start = 8372
    _globals["_ORDERMESSAGE_ORDERSURFACE"]._serialized_end = 8399
    _globals["_ORDERMESSAGE_ORDERSTATUS"]._serialized_start = 8401
    _globals["_ORDERMESSAGE_ORDERSTATUS"]._serialized_end = 8455
    _globals["_PAYMENTINVITEMESSAGE"]._serialized_start = 8458
    _globals["_PAYMENTINVITEMESSAGE"]._serialized_end = 8637
    _globals["_PAYMENTINVITEMESSAGE_SERVICETYPE"]._serialized_start = 8581
    _globals["_PAYMENTINVITEMESSAGE_SERVICETYPE"]._serialized_end = 8637
    _globals["_HIGHLYSTRUCTUREDMESSAGE"]._serialized_start = 8640
    _globals["_HIGHLYSTRUCTUREDMESSAGE"]._serialized_end = 10128
    _globals[
        "_HIGHLYSTRUCTUREDMESSAGE_HSMLOCALIZABLEPARAMETER"
    ]._serialized_start = 8966
    _globals["_HIGHLYSTRUCTUREDMESSAGE_HSMLOCALIZABLEPARAMETER"]._serialized_end = 10128
    _globals[
        "_HIGHLYSTRUCTUREDMESSAGE_HSMLOCALIZABLEPARAMETER_HSMDATETIME"
    ]._serialized_start = 9211
    _globals[
        "_HIGHLYSTRUCTUREDMESSAGE_HSMLOCALIZABLEPARAMETER_HSMDATETIME"
    ]._serialized_end = 10057
    _globals[
        "_HIGHLYSTRUCTUREDMESSAGE_HSMLOCALIZABLEPARAMETER_HSMDATETIME_HSMDATETIMECOMPONENT"
    ]._serialized_start = 9471
    _globals[
        "_HIGHLYSTRUCTUREDMESSAGE_HSMLOCALIZABLEPARAMETER_HSMDATETIME_HSMDATETIMECOMPONENT"
    ]._serialized_end = 9997
    _globals[
        "_HIGHLYSTRUCTUREDMESSAGE_HSMLOCALIZABLEPARAMETER_HSMDATETIME_HSMDATETIMECOMPONENT_CALENDARTYPE"
    ]._serialized_start = 9842
    _globals[
        "_HIGHLYSTRUCTUREDMESSAGE_HSMLOCALIZABLEPARAMETER_HSMDATETIME_HSMDATETIMECOMPONENT_CALENDARTYPE"
    ]._serialized_end = 9888
    _globals[
        "_HIGHLYSTRUCTUREDMESSAGE_HSMLOCALIZABLEPARAMETER_HSMDATETIME_HSMDATETIMECOMPONENT_DAYOFWEEKTYPE"
    ]._serialized_start = 9890
    _globals[
        "_HIGHLYSTRUCTUREDMESSAGE_HSMLOCALIZABLEPARAMETER_HSMDATETIME_HSMDATETIMECOMPONENT_DAYOFWEEKTYPE"
    ]._serialized_end = 9997
    _globals[
        "_HIGHLYSTRUCTUREDMESSAGE_HSMLOCALIZABLEPARAMETER_HSMDATETIME_HSMDATETIMEUNIXEPOCH"
    ]._serialized_start = 9999
    _globals[
        "_HIGHLYSTRUCTUREDMESSAGE_HSMLOCALIZABLEPARAMETER_HSMDATETIME_HSMDATETIMEUNIXEPOCH"
    ]._serialized_end = 10040
    _globals[
        "_HIGHLYSTRUCTUREDMESSAGE_HSMLOCALIZABLEPARAMETER_HSMCURRENCY"
    ]._serialized_start = 10059
    _globals[
        "_HIGHLYSTRUCTUREDMESSAGE_HSMLOCALIZABLEPARAMETER_HSMCURRENCY"
    ]._serialized_end = 10114
    _globals["_PEERDATAOPERATIONREQUESTRESPONSEMESSAGE"]._serialized_start = 10131
    _globals["_PEERDATAOPERATIONREQUESTRESPONSEMESSAGE"]._serialized_end = 12539
    _globals[
        "_PEERDATAOPERATIONREQUESTRESPONSEMESSAGE_PEERDATAOPERATIONRESULT"
    ]._serialized_start = 10397
    _globals[
        "_PEERDATAOPERATIONREQUESTRESPONSEMESSAGE_PEERDATAOPERATIONRESULT"
    ]._serialized_end = 12539
    _globals[
        "_PEERDATAOPERATIONREQUESTRESPONSEMESSAGE_PEERDATAOPERATIONRESULT_COMPANIONMETANONCEFETCHRESPONSE"
    ]._serialized_start = 11339
    _globals[
        "_PEERDATAOPERATIONREQUESTRESPONSEMESSAGE_PEERDATAOPERATIONRESULT_COMPANIONMETANONCEFETCHRESPONSE"
    ]._serialized_end = 11387
    _globals[
        "_PEERDATAOPERATIONREQUESTRESPONSEMESSAGE_PEERDATAOPERATIONRESULT_WAFFLENONCEFETCHRESPONSE"
    ]._serialized_start = 11389
    _globals[
        "_PEERDATAOPERATIONREQUESTRESPONSEMESSAGE_PEERDATAOPERATIONRESULT_WAFFLENONCEFETCHRESPONSE"
    ]._serialized_end = 11449
    _globals[
        "_PEERDATAOPERATIONREQUESTRESPONSEMESSAGE_PEERDATAOPERATIONRESULT_FULLHISTORYSYNCONDEMANDREQUESTRESPONSE"
    ]._serialized_start = 11452
    _globals[
        "_PEERDATAOPERATIONREQUESTRESPONSEMESSAGE_PEERDATAOPERATIONRESULT_FULLHISTORYSYNCONDEMANDREQUESTRESPONSE"
    ]._serialized_end = 11719
    _globals[
        "_PEERDATAOPERATIONREQUESTRESPONSEMESSAGE_PEERDATAOPERATIONRESULT_PLACEHOLDERMESSAGERESENDRESPONSE"
    ]._serialized_start = 11721
    _globals[
        "_PEERDATAOPERATIONREQUESTRESPONSEMESSAGE_PEERDATAOPERATIONRESULT_PLACEHOLDERMESSAGERESENDRESPONSE"
    ]._serialized_end = 11784
    _globals[
        "_PEERDATAOPERATIONREQUESTRESPONSEMESSAGE_PEERDATAOPERATIONRESULT_LINKPREVIEWRESPONSE"
    ]._serialized_start = 11787
    _globals[
        "_PEERDATAOPERATIONREQUESTRESPONSEMESSAGE_PEERDATAOPERATIONRESULT_LINKPREVIEWRESPONSE"
    ]._serialized_end = 12282
    _globals[
        "_PEERDATAOPERATIONREQUESTRESPONSEMESSAGE_PEERDATAOPERATIONRESULT_LINKPREVIEWRESPONSE_LINKPREVIEWHIGHQUALITYTHUMBNAIL"
    ]._serialized_start = 12100
    _globals[
        "_PEERDATAOPERATIONREQUESTRESPONSEMESSAGE_PEERDATAOPERATIONRESULT_LINKPREVIEWRESPONSE_LINKPREVIEWHIGHQUALITYTHUMBNAIL"
    ]._serialized_end = 12282
    _globals[
        "_PEERDATAOPERATIONREQUESTRESPONSEMESSAGE_PEERDATAOPERATIONRESULT_FULLHISTORYSYNCONDEMANDRESPONSECODE"
    ]._serialized_start = 12285
    _globals[
        "_PEERDATAOPERATIONREQUESTRESPONSEMESSAGE_PEERDATAOPERATIONRESULT_FULLHISTORYSYNCONDEMANDRESPONSECODE"
    ]._serialized_end = 12539
    _globals["_HISTORYSYNCNOTIFICATION"]._serialized_start = 12542
    _globals["_HISTORYSYNCNOTIFICATION"]._serialized_end = 13209
    _globals["_HISTORYSYNCNOTIFICATION_HISTORYSYNCTYPE"]._serialized_start = 13055
    _globals["_HISTORYSYNCNOTIFICATION_HISTORYSYNCTYPE"]._serialized_end = 13209
    _globals["_REQUESTWELCOMEMESSAGEMETADATA"]._serialized_start = 13212
    _globals["_REQUESTWELCOMEMESSAGEMETADATA"]._serialized_end = 13376
    _globals["_REQUESTWELCOMEMESSAGEMETADATA_LOCALCHATSTATE"]._serialized_start = 13334
    _globals["_REQUESTWELCOMEMESSAGEMETADATA_LOCALCHATSTATE"]._serialized_end = 13376
    _globals["_PROTOCOLMESSAGE"]._serialized_start = 13379
    _globals["_PROTOCOLMESSAGE"]._serialized_end = 15410
    _globals["_PROTOCOLMESSAGE_TYPE"]._serialized_start = 14750
    _globals["_PROTOCOLMESSAGE_TYPE"]._serialized_end = 15410
    _globals["_CLOUDAPITHREADCONTROLNOTIFICATION"]._serialized_start = 15413
    _globals["_CLOUDAPITHREADCONTROLNOTIFICATION"]._serialized_end = 15706
    _globals[
        "_CLOUDAPITHREADCONTROLNOTIFICATION_CLOUDAPITHREADCONTROL"
    ]._serialized_start = 15631
    _globals[
        "_CLOUDAPITHREADCONTROLNOTIFICATION_CLOUDAPITHREADCONTROL"
    ]._serialized_end = 15706
    _globals["_BOTFEEDBACKMESSAGE"]._serialized_start = 15709
    _globals["_BOTFEEDBACKMESSAGE"]._serialized_end = 16926
    _globals["_BOTFEEDBACKMESSAGE_REPORTKIND"]._serialized_start = 15970
    _globals["_BOTFEEDBACKMESSAGE_REPORTKIND"]._serialized_end = 15995
    _globals[
        "_BOTFEEDBACKMESSAGE_BOTFEEDBACKKINDMULTIPLEPOSITIVE"
    ]._serialized_start = 15997
    _globals[
        "_BOTFEEDBACKMESSAGE_BOTFEEDBACKKINDMULTIPLEPOSITIVE"
    ]._serialized_end = 16074
    _globals[
        "_BOTFEEDBACKMESSAGE_BOTFEEDBACKKINDMULTIPLENEGATIVE"
    ]._serialized_start = 16077
    _globals[
        "_BOTFEEDBACKMESSAGE_BOTFEEDBACKKINDMULTIPLENEGATIVE"
    ]._serialized_end = 16536
    _globals["_BOTFEEDBACKMESSAGE_BOTFEEDBACKKIND"]._serialized_start = 16539
    _globals["_BOTFEEDBACKMESSAGE_BOTFEEDBACKKIND"]._serialized_end = 16926
    _globals["_VIDEOMESSAGE"]._serialized_start = 16929
    _globals["_VIDEOMESSAGE"]._serialized_end = 17750
    _globals["_VIDEOMESSAGE_ATTRIBUTION"]._serialized_start = 17705
    _globals["_VIDEOMESSAGE_ATTRIBUTION"]._serialized_end = 17750
    _globals["_EXTENDEDTEXTMESSAGE"]._serialized_start = 17753
    _globals["_EXTENDEDTEXTMESSAGE"]._serialized_end = 18980
    _globals["_EXTENDEDTEXTMESSAGE_INVITELINKGROUPTYPE"]._serialized_start = 18645
    _globals["_EXTENDEDTEXTMESSAGE_INVITELINKGROUPTYPE"]._serialized_end = 18717
    _globals["_EXTENDEDTEXTMESSAGE_PREVIEWTYPE"]._serialized_start = 18719
    _globals["_EXTENDEDTEXTMESSAGE_PREVIEWTYPE"]._serialized_end = 18813
    _globals["_EXTENDEDTEXTMESSAGE_FONTTYPE"]._serialized_start = 18816
    _globals["_EXTENDEDTEXTMESSAGE_FONTTYPE"]._serialized_end = 18980
    _globals["_INVOICEMESSAGE"]._serialized_start = 18983
    _globals["_INVOICEMESSAGE"]._serialized_end = 19359
    _globals["_INVOICEMESSAGE_ATTACHMENTTYPE"]._serialized_start = 19323
    _globals["_INVOICEMESSAGE_ATTACHMENTTYPE"]._serialized_end = 19359
    _globals["_IMAGEMESSAGE"]._serialized_start = 19362
    _globals["_IMAGEMESSAGE"]._serialized_end = 20271
    _globals["_IMAGEMESSAGE_IMAGESOURCETYPE"]._serialized_start = 20203
    _globals["_IMAGEMESSAGE_IMAGESOURCETYPE"]._serialized_end = 20271
    _globals["_CONTEXTINFO"]._serialized_start = 20274
    _globals["_CONTEXTINFO"]._serialized_end = 23686
    _globals["_CONTEXTINFO_FORWARDEDNEWSLETTERMESSAGEINFO"]._serialized_start = 21945
    _globals["_CONTEXTINFO_FORWARDEDNEWSLETTERMESSAGEINFO"]._serialized_end = 22231
    _globals[
        "_CONTEXTINFO_FORWARDEDNEWSLETTERMESSAGEINFO_CONTENTTYPE"
    ]._serialized_start = 22174
    _globals[
        "_CONTEXTINFO_FORWARDEDNEWSLETTERMESSAGEINFO_CONTENTTYPE"
    ]._serialized_end = 22231
    _globals["_CONTEXTINFO_EXTERNALADREPLYINFO"]._serialized_start = 22234
    _globals["_CONTEXTINFO_EXTERNALADREPLYINFO"]._serialized_end = 22861
    _globals["_CONTEXTINFO_EXTERNALADREPLYINFO_MEDIATYPE"]._serialized_start = 22818
    _globals["_CONTEXTINFO_EXTERNALADREPLYINFO_MEDIATYPE"]._serialized_end = 22861
    _globals["_CONTEXTINFO_ADREPLYINFO"]._serialized_start = 22864
    _globals["_CONTEXTINFO_ADREPLYINFO"]._serialized_end = 23059
    _globals["_CONTEXTINFO_ADREPLYINFO_MEDIATYPE"]._serialized_start = 22818
    _globals["_CONTEXTINFO_ADREPLYINFO_MEDIATYPE"]._serialized_end = 22861
    _globals["_CONTEXTINFO_FEATUREELIGIBILITIES"]._serialized_start = 23061
    _globals["_CONTEXTINFO_FEATUREELIGIBILITIES"]._serialized_end = 23162
    _globals["_CONTEXTINFO_DATASHARINGCONTEXT"]._serialized_start = 23165
    _globals["_CONTEXTINFO_DATASHARINGCONTEXT"]._serialized_end = 23496
    _globals["_CONTEXTINFO_DATASHARINGCONTEXT_PARAMETERS"]._serialized_start = 23335
    _globals["_CONTEXTINFO_DATASHARINGCONTEXT_PARAMETERS"]._serialized_end = 23496
    _globals["_CONTEXTINFO_FORWARDEDAIBOTMESSAGEINFO"]._serialized_start = 23498
    _globals["_CONTEXTINFO_FORWARDEDAIBOTMESSAGEINFO"]._serialized_end = 23579
    _globals["_CONTEXTINFO_UTMINFO"]._serialized_start = 23581
    _globals["_CONTEXTINFO_UTMINFO"]._serialized_end = 23630
    _globals["_CONTEXTINFO_BUSINESSMESSAGEFORWARDINFO"]._serialized_start = 23632
    _globals["_CONTEXTINFO_BUSINESSMESSAGEFORWARDINFO"]._serialized_end = 23686
    _globals["_BOTPLUGINMETADATA"]._serialized_start = 23689
    _globals["_BOTPLUGINMETADATA"]._serialized_end = 24294
    _globals["_BOTPLUGINMETADATA_PLUGINTYPE"]._serialized_start = 24206
    _globals["_BOTPLUGINMETADATA_PLUGINTYPE"]._serialized_end = 24241
    _globals["_BOTPLUGINMETADATA_SEARCHPROVIDER"]._serialized_start = 24243
    _globals["_BOTPLUGINMETADATA_SEARCHPROVIDER"]._serialized_end = 24294
    _globals["_BOTMEDIAMETADATA"]._serialized_start = 24297
    _globals["_BOTMEDIAMETADATA"]._serialized_end = 24571
    _globals["_BOTMEDIAMETADATA_ORIENTATIONTYPE"]._serialized_start = 24521
    _globals["_BOTMEDIAMETADATA_ORIENTATIONTYPE"]._serialized_end = 24571
    _globals["_BOTREMINDERMETADATA"]._serialized_start = 24574
    _globals["_BOTREMINDERMETADATA"]._serialized_end = 24983
    _globals["_BOTREMINDERMETADATA_REMINDERFREQUENCY"]._serialized_start = 24838
    _globals["_BOTREMINDERMETADATA_REMINDERFREQUENCY"]._serialized_end = 24917
    _globals["_BOTREMINDERMETADATA_REMINDERACTION"]._serialized_start = 24919
    _globals["_BOTREMINDERMETADATA_REMINDERACTION"]._serialized_end = 24983
    _globals["_BOTMODELMETADATA"]._serialized_start = 24986
    _globals["_BOTMODELMETADATA"]._serialized_end = 25268
    _globals["_BOTMODELMETADATA_PREMIUMMODELSTATUS"]._serialized_start = 25156
    _globals["_BOTMODELMETADATA_PREMIUMMODELSTATUS"]._serialized_end = 25215
    _globals["_BOTMODELMETADATA_MODELTYPE"]._serialized_start = 25217
    _globals["_BOTMODELMETADATA_MODELTYPE"]._serialized_end = 25268
    _globals["_BOTCAPABILITYMETADATA"]._serialized_start = 25271
    _globals["_BOTCAPABILITYMETADATA"]._serialized_end = 25479
    _globals["_BOTCAPABILITYMETADATA_BOTCAPABILITYTYPE"]._serialized_start = 25378
    _globals["_BOTCAPABILITYMETADATA_BOTCAPABILITYTYPE"]._serialized_end = 25479
    _globals["_BOTIMAGINEMETADATA"]._serialized_start = 25482
    _globals["_BOTIMAGINEMETADATA"]._serialized_end = 25646
    _globals["_BOTIMAGINEMETADATA_IMAGINETYPE"]._serialized_start = 25576
    _globals["_BOTIMAGINEMETADATA_IMAGINETYPE"]._serialized_end = 25646
    _globals["_MESSAGEASSOCIATION"]._serialized_start = 25649
    _globals["_MESSAGEASSOCIATION"]._serialized_end = 25996
    _globals["_MESSAGEASSOCIATION_ASSOCIATIONTYPE"]._serialized_start = 25822
    _globals["_MESSAGEASSOCIATION_ASSOCIATIONTYPE"]._serialized_end = 25996
    _globals["_MESSAGECONTEXTINFO"]._serialized_start = 25999
    _globals["_MESSAGECONTEXTINFO"]._serialized_end = 26586
    _globals["_MESSAGECONTEXTINFO_MESSAGEADDONEXPIRYTYPE"]._serialized_start = 26525
    _globals["_MESSAGECONTEXTINFO_MESSAGEADDONEXPIRYTYPE"]._serialized_end = 26586
    _globals["_HYDRATEDTEMPLATEBUTTON"]._serialized_start = 26589
    _globals["_HYDRATEDTEMPLATEBUTTON"]._serialized_end = 27290
    _globals["_HYDRATEDTEMPLATEBUTTON_HYDRATEDURLBUTTON"]._serialized_start = 26893
    _globals["_HYDRATEDTEMPLATEBUTTON_HYDRATEDURLBUTTON"]._serialized_end = 27147
    _globals[
        "_HYDRATEDTEMPLATEBUTTON_HYDRATEDURLBUTTON_WEBVIEWPRESENTATIONTYPE"
    ]._serialized_start = 27089
    _globals[
        "_HYDRATEDTEMPLATEBUTTON_HYDRATEDURLBUTTON_WEBVIEWPRESENTATIONTYPE"
    ]._serialized_end = 27147
    _globals["_HYDRATEDTEMPLATEBUTTON_HYDRATEDCALLBUTTON"]._serialized_start = 27149
    _globals["_HYDRATEDTEMPLATEBUTTON_HYDRATEDCALLBUTTON"]._serialized_end = 27211
    _globals[
        "_HYDRATEDTEMPLATEBUTTON_HYDRATEDQUICKREPLYBUTTON"
    ]._serialized_start = 27213
    _globals["_HYDRATEDTEMPLATEBUTTON_HYDRATEDQUICKREPLYBUTTON"]._serialized_end = 27272
    _globals["_PAYMENTBACKGROUND"]._serialized_start = 27293
    _globals["_PAYMENTBACKGROUND"]._serialized_end = 27736
    _globals["_PAYMENTBACKGROUND_MEDIADATA"]._serialized_start = 27583
    _globals["_PAYMENTBACKGROUND_MEDIADATA"]._serialized_end = 27702
    _globals["_PAYMENTBACKGROUND_TYPE"]._serialized_start = 27704
    _globals["_PAYMENTBACKGROUND_TYPE"]._serialized_end = 27736
    _globals["_DISAPPEARINGMODE"]._serialized_start = 27739
    _globals["_DISAPPEARINGMODE"]._serialized_end = 28172
    _globals["_DISAPPEARINGMODE_TRIGGER"]._serialized_start = 27938
    _globals["_DISAPPEARINGMODE_TRIGGER"]._serialized_end = 28065
    _globals["_DISAPPEARINGMODE_INITIATOR"]._serialized_start = 28067
    _globals["_DISAPPEARINGMODE_INITIATOR"]._serialized_end = 28172
    _globals["_PROCESSEDVIDEO"]._serialized_start = 28175
    _globals["_PROCESSEDVIDEO"]._serialized_end = 28445
    _globals["_PROCESSEDVIDEO_VIDEOQUALITY"]._serialized_start = 28388
    _globals["_PROCESSEDVIDEO_VIDEOQUALITY"]._serialized_end = 28445
    _globals["_MESSAGE"]._serialized_start = 28448
    _globals["_MESSAGE"]._serialized_end = 33474
    _globals["_ALBUMMESSAGE"]._serialized_start = 33476
    _globals["_ALBUMMESSAGE"]._serialized_end = 33599
    _globals["_MESSAGEHISTORYBUNDLE"]._serialized_start = 33602
    _globals["_MESSAGEHISTORYBUNDLE"]._serialized_end = 33825
    _globals["_ENCEVENTRESPONSEMESSAGE"]._serialized_start = 33827
    _globals["_ENCEVENTRESPONSEMESSAGE"]._serialized_end = 33942
    _globals["_EVENTMESSAGE"]._serialized_start = 33945
    _globals["_EVENTMESSAGE"]._serialized_end = 34203
    _globals["_COMMENTMESSAGE"]._serialized_start = 34205
    _globals["_COMMENTMESSAGE"]._serialized_end = 34314
    _globals["_ENCCOMMENTMESSAGE"]._serialized_start = 34316
    _globals["_ENCCOMMENTMESSAGE"]._serialized_end = 34418
    _globals["_ENCREACTIONMESSAGE"]._serialized_start = 34420
    _globals["_ENCREACTIONMESSAGE"]._serialized_end = 34523
    _globals["_KEEPINCHATMESSAGE"]._serialized_start = 34525
    _globals["_KEEPINCHATMESSAGE"]._serialized_end = 34647
    _globals["_POLLRESULTSNAPSHOTMESSAGE"]._serialized_start = 34650
    _globals["_POLLRESULTSNAPSHOTMESSAGE"]._serialized_end = 34875
    _globals["_POLLRESULTSNAPSHOTMESSAGE_POLLVOTE"]._serialized_start = 34820
    _globals["_POLLRESULTSNAPSHOTMESSAGE_POLLVOTE"]._serialized_end = 34875
    _globals["_POLLVOTEMESSAGE"]._serialized_start = 34877
    _globals["_POLLVOTEMESSAGE"]._serialized_end = 34919
    _globals["_POLLENCVALUE"]._serialized_start = 34921
    _globals["_POLLENCVALUE"]._serialized_end = 34970
    _globals["_POLLUPDATEMESSAGEMETADATA"]._serialized_start = 34972
    _globals["_POLLUPDATEMESSAGEMETADATA"]._serialized_end = 34999
    _globals["_POLLUPDATEMESSAGE"]._serialized_start = 35002
    _globals["_POLLUPDATEMESSAGE"]._serialized_end = 35213
    _globals["_POLLCREATIONMESSAGE"]._serialized_start = 35216
    _globals["_POLLCREATIONMESSAGE"]._serialized_end = 35513
    _globals["_POLLCREATIONMESSAGE_OPTION"]._serialized_start = 35465
    _globals["_POLLCREATIONMESSAGE_OPTION"]._serialized_end = 35513
    _globals["_STICKERSYNCRMRMESSAGE"]._serialized_start = 35515
    _globals["_STICKERSYNCRMRMESSAGE"]._serialized_end = 35601
    _globals["_REACTIONMESSAGE"]._serialized_start = 35603
    _globals["_REACTIONMESSAGE"]._serialized_end = 35717
    _globals["_FUTUREPROOFMESSAGE"]._serialized_start = 35719
    _globals["_FUTUREPROOFMESSAGE"]._serialized_end = 35784
    _globals["_DEVICESENTMESSAGE"]._serialized_start = 35786
    _globals["_DEVICESENTMESSAGE"]._serialized_end = 35889
    _globals["_REQUESTPHONENUMBERMESSAGE"]._serialized_start = 35891
    _globals["_REQUESTPHONENUMBERMESSAGE"]._serialized_end = 35971
    _globals["_NEWSLETTERADMININVITEMESSAGE"]._serialized_start = 35974
    _globals["_NEWSLETTERADMININVITEMESSAGE"]._serialized_end = 36170
    _globals["_PRODUCTMESSAGE"]._serialized_start = 36173
    _globals["_PRODUCTMESSAGE"]._serialized_end = 36832
    _globals["_PRODUCTMESSAGE_PRODUCTSNAPSHOT"]._serialized_start = 36437
    _globals["_PRODUCTMESSAGE_PRODUCTSNAPSHOT"]._serialized_end = 36722
    _globals["_PRODUCTMESSAGE_CATALOGSNAPSHOT"]._serialized_start = 36724
    _globals["_PRODUCTMESSAGE_CATALOGSNAPSHOT"]._serialized_end = 36832
    _globals["_TEMPLATEBUTTONREPLYMESSAGE"]._serialized_start = 36835
    _globals["_TEMPLATEBUTTONREPLYMESSAGE"]._serialized_end = 37023
    _globals["_TEMPLATEMESSAGE"]._serialized_start = 37026
    _globals["_TEMPLATEMESSAGE"]._serialized_end = 38462
    _globals["_TEMPLATEMESSAGE_HYDRATEDFOURROWTEMPLATE"]._serialized_start = 37456
    _globals["_TEMPLATEMESSAGE_HYDRATEDFOURROWTEMPLATE"]._serialized_end = 37931
    _globals["_TEMPLATEMESSAGE_FOURROWTEMPLATE"]._serialized_start = 37934
    _globals["_TEMPLATEMESSAGE_FOURROWTEMPLATE"]._serialized_end = 38452
    _globals["_STICKERMESSAGE"]._serialized_start = 38465
    _globals["_STICKERMESSAGE"]._serialized_end = 38927
    _globals["_LIVELOCATIONMESSAGE"]._serialized_start = 38930
    _globals["_LIVELOCATIONMESSAGE"]._serialized_end = 39228
    _globals["_CANCELPAYMENTREQUESTMESSAGE"]._serialized_start = 39230
    _globals["_CANCELPAYMENTREQUESTMESSAGE"]._serialized_end = 39294
    _globals["_DECLINEPAYMENTREQUESTMESSAGE"]._serialized_start = 39296
    _globals["_DECLINEPAYMENTREQUESTMESSAGE"]._serialized_end = 39361
    _globals["_REQUESTPAYMENTMESSAGE"]._serialized_start = 39364
    _globals["_REQUESTPAYMENTMESSAGE"]._serialized_end = 39631
    _globals["_SENDPAYMENTMESSAGE"]._serialized_start = 39634
    _globals["_SENDPAYMENTMESSAGE"]._serialized_end = 39810
    _globals["_CONTACTSARRAYMESSAGE"]._serialized_start = 39813
    _globals["_CONTACTSARRAYMESSAGE"]._serialized_end = 39962
    _globals["_INITIALSECURITYNOTIFICATIONSETTINGSYNC"]._serialized_start = 39964
    _globals["_INITIALSECURITYNOTIFICATIONSETTINGSYNC"]._serialized_end = 40041
    _globals["_PEERDATAOPERATIONREQUESTMESSAGE"]._serialized_start = 40044
    _globals["_PEERDATAOPERATIONREQUESTMESSAGE"]._serialized_end = 41291
    _globals[
        "_PEERDATAOPERATIONREQUESTMESSAGE_PLACEHOLDERMESSAGERESENDREQUEST"
    ]._serialized_start = 40733
    _globals[
        "_PEERDATAOPERATIONREQUESTMESSAGE_PLACEHOLDERMESSAGERESENDREQUEST"
    ]._serialized_end = 40808
    _globals[
        "_PEERDATAOPERATIONREQUESTMESSAGE_FULLHISTORYSYNCONDEMANDREQUEST"
    ]._serialized_start = 40811
    _globals[
        "_PEERDATAOPERATIONREQUESTMESSAGE_FULLHISTORYSYNCONDEMANDREQUEST"
    ]._serialized_end = 41013
    _globals[
        "_PEERDATAOPERATIONREQUESTMESSAGE_HISTORYSYNCONDEMANDREQUEST"
    ]._serialized_start = 41016
    _globals[
        "_PEERDATAOPERATIONREQUESTMESSAGE_HISTORYSYNCONDEMANDREQUEST"
    ]._serialized_end = 41183
    _globals[
        "_PEERDATAOPERATIONREQUESTMESSAGE_REQUESTURLPREVIEW"
    ]._serialized_start = 41185
    _globals[
        "_PEERDATAOPERATIONREQUESTMESSAGE_REQUESTURLPREVIEW"
    ]._serialized_end = 41245
    _globals[
        "_PEERDATAOPERATIONREQUESTMESSAGE_REQUESTSTICKERREUPLOAD"
    ]._serialized_start = 41247
    _globals[
        "_PEERDATAOPERATIONREQUESTMESSAGE_REQUESTSTICKERREUPLOAD"
    ]._serialized_end = 41291
    _globals["_FULLHISTORYSYNCONDEMANDREQUESTMETADATA"]._serialized_start = 41293
    _globals["_FULLHISTORYSYNCONDEMANDREQUESTMETADATA"]._serialized_end = 41352
    _globals["_APPSTATEFATALEXCEPTIONNOTIFICATION"]._serialized_start = 41354
    _globals["_APPSTATEFATALEXCEPTIONNOTIFICATION"]._serialized_end = 41434
    _globals["_APPSTATESYNCKEYREQUEST"]._serialized_start = 41436
    _globals["_APPSTATESYNCKEYREQUEST"]._serialized_end = 41514
    _globals["_APPSTATESYNCKEYSHARE"]._serialized_start = 41516
    _globals["_APPSTATESYNCKEYSHARE"]._serialized_end = 41588
    _globals["_APPSTATESYNCKEYDATA"]._serialized_start = 41590
    _globals["_APPSTATESYNCKEYDATA"]._serialized_end = 41715
    _globals["_APPSTATESYNCKEYFINGERPRINT"]._serialized_start = 41717
    _globals["_APPSTATESYNCKEYFINGERPRINT"]._serialized_end = 41809
    _globals["_APPSTATESYNCKEYID"]._serialized_start = 41811
    _globals["_APPSTATESYNCKEYID"]._serialized_end = 41845
    _globals["_APPSTATESYNCKEY"]._serialized_start = 41847
    _globals["_APPSTATESYNCKEY"]._serialized_end = 41974
    _globals["_CHAT"]._serialized_start = 41976
    _globals["_CHAT"]._serialized_end = 42015
    _globals["_CALL"]._serialized_start = 42018
    _globals["_CALL"]._serialized_end = 42165
    _globals["_AUDIOMESSAGE"]._serialized_start = 42168
    _globals["_AUDIOMESSAGE"]._serialized_end = 42538
    _globals["_DOCUMENTMESSAGE"]._serialized_start = 42541
    _globals["_DOCUMENTMESSAGE"]._serialized_end = 43043
    _globals["_LOCATIONMESSAGE"]._serialized_start = 43046
    _globals["_LOCATIONMESSAGE"]._serialized_end = 43356
    _globals["_CONTACTMESSAGE"]._serialized_start = 43358
    _globals["_CONTACTMESSAGE"]._serialized_end = 43463
    _globals["_SENDERKEYDISTRIBUTIONMESSAGE"]._serialized_start = 43465
    _globals["_SENDERKEYDISTRIBUTIONMESSAGE"]._serialized_end = 43557
    _globals["_BOTAVATARMETADATA"]._serialized_start = 43559
    _globals["_BOTAVATARMETADATA"]._serialized_end = 43674
    _globals["_BOTSUGGESTEDPROMPTMETADATA"]._serialized_start = 43676
    _globals["_BOTSUGGESTEDPROMPTMETADATA"]._serialized_end = 43759
    _globals["_BOTMEMORYMETADATA"]._serialized_start = 43762
    _globals["_BOTMEMORYMETADATA"]._serialized_end = 43911
    _globals["_BOTMEMORYFACT"]._serialized_start = 43913
    _globals["_BOTMEMORYFACT"]._serialized_end = 43958
    _globals["_BOTSESSIONMETADATA"]._serialized_start = 43960
    _globals["_BOTSESSIONMETADATA"]._serialized_end = 44059
    _globals["_BOTMEMUMETADATA"]._serialized_start = 44061
    _globals["_BOTMEMUMETADATA"]._serialized_end = 44135
    _globals["_BOTPROGRESSINDICATORMETADATA"]._serialized_start = 44137
    _globals["_BOTPROGRESSINDICATORMETADATA"]._serialized_end = 44196
    _globals["_BOTMETADATA"]._serialized_start = 44199
    _globals["_BOTMETADATA"]._serialized_end = 45032
    _globals["_DEVICELISTMETADATA"]._serialized_start = 45035
    _globals["_DEVICELISTMETADATA"]._serialized_end = 45328
    _globals["_EMBEDDEDMESSAGE"]._serialized_start = 45330
    _globals["_EMBEDDEDMESSAGE"]._serialized_end = 45410
    _globals["_EMBEDDEDMUSIC"]._serialized_start = 45413
    _globals["_EMBEDDEDMUSIC"]._serialized_end = 45678
    _globals["_EMBEDDEDCONTENT"]._serialized_start = 45681
    _globals["_EMBEDDEDCONTENT"]._serialized_end = 45831
    _globals["_TAPLINKACTION"]._serialized_start = 45833
    _globals["_TAPLINKACTION"]._serialized_end = 45879
    _globals["_INTERACTIVEANNOTATION"]._serialized_start = 45882
    _globals["_INTERACTIVEANNOTATION"]._serialized_end = 46274
    _globals["_POINT"]._serialized_start = 46276
    _globals["_POINT"]._serialized_end = 46347
    _globals["_LOCATION"]._serialized_start = 46349
    _globals["_LOCATION"]._serialized_end = 46424
    _globals["_TEMPLATEBUTTON"]._serialized_start = 46427
    _globals["_TEMPLATEBUTTON"]._serialized_end = 47060
    _globals["_TEMPLATEBUTTON_CALLBUTTON"]._serialized_start = 46675
    _globals["_TEMPLATEBUTTON_CALLBUTTON"]._serialized_end = 46817
    _globals["_TEMPLATEBUTTON_URLBUTTON"]._serialized_start = 46820
    _globals["_TEMPLATEBUTTON_URLBUTTON"]._serialized_end = 46953
    _globals["_TEMPLATEBUTTON_QUICKREPLYBUTTON"]._serialized_start = 46955
    _globals["_TEMPLATEBUTTON_QUICKREPLYBUTTON"]._serialized_end = 47050
    _globals["_MONEY"]._serialized_start = 47062
    _globals["_MONEY"]._serialized_end = 47122
    _globals["_ACTIONLINK"]._serialized_start = 47124
    _globals["_ACTIONLINK"]._serialized_end = 47170
    _globals["_GROUPMENTION"]._serialized_start = 47172
    _globals["_GROUPMENTION"]._serialized_end = 47226
    _globals["_MESSAGESECRETMESSAGE"]._serialized_start = 47228
    _globals["_MESSAGESECRETMESSAGE"]._serialized_end = 47302
    _globals["_MEDIANOTIFYMESSAGE"]._serialized_start = 47304
    _globals["_MEDIANOTIFYMESSAGE"]._serialized_end = 47391
    _globals["_LIDMIGRATIONMAPPINGSYNCMESSAGE"]._serialized_start = 47393
    _globals["_LIDMIGRATIONMAPPINGSYNCMESSAGE"]._serialized_end = 47456
# @@protoc_insertion_point(module_scope)
